# modulegraph cross reference for pyi_rth__tkinter.py, pyi_rth_multiprocessing.py, pyi_rth_win32api.py, tk_rocket_units.py

`pyi_rth__tkinter.py` Script
imports: os • sys
imported by: tk_rocket_units.py
`pyi_rth_multiprocessing.py` Script
imports: multiprocessing • multiprocessing.popen_fork • multiprocessing.popen_spawn_posix • multiprocessing.popen_spawn_win32 • multiprocessing.spawn • os • re • subprocess • sys
imported by: tk_rocket_units.py
`pyi_rth_win32api.py` Script
imports: pywintypes
imported by: tk_rocket_units.py
`tk_rocket_units.py` Script
imports: __future__ • _bootlocale • _collections_abc • _weakrefset • abc • builtins • codecs • collections • collections.abc • copyreg • decimal • encodings • encodings.aliases • encodings.ascii • encodings.base64_codec • encodings.big5 • encodings.big5hkscs • encodings.bz2_codec • encodings.charmap • encodings.cp037 • encodings.cp1006 • encodings.cp1026 • encodings.cp1125 • encodings.cp1140 • encodings.cp1250 • encodings.cp1251 • encodings.cp1252 • encodings.cp1253 • encodings.cp1254 • encodings.cp1255 • encodings.cp1256 • encodings.cp1257 • encodings.cp1258 • encodings.cp273 • encodings.cp424 • encodings.cp437 • encodings.cp500 • encodings.cp65001 • encodings.cp720 • encodings.cp737 • encodings.cp775 • encodings.cp850 • encodings.cp852 • encodings.cp855 • encodings.cp856 • encodings.cp857 • encodings.cp858 • encodings.cp860 • encodings.cp861 • encodings.cp862 • encodings.cp863 • encodings.cp864 • encodings.cp865 • encodings.cp866 • encodings.cp869 • encodings.cp874 • encodings.cp875 • encodings.cp932 • encodings.cp949 • encodings.cp950 • encodings.euc_jis_2004 • encodings.euc_jisx0213 • encodings.euc_jp • encodings.euc_kr • encodings.gb18030 • encodings.gb2312 • encodings.gbk • encodings.hex_codec • encodings.hp_roman8 • encodings.hz • encodings.idna • encodings.iso2022_jp • encodings.iso2022_jp_1 • encodings.iso2022_jp_2 • encodings.iso2022_jp_2004 • encodings.iso2022_jp_3 • encodings.iso2022_jp_ext • encodings.iso2022_kr • encodings.iso8859_1 • encodings.iso8859_10 • encodings.iso8859_11 • encodings.iso8859_13 • encodings.iso8859_14 • encodings.iso8859_15 • encodings.iso8859_16 • encodings.iso8859_2 • encodings.iso8859_3 • encodings.iso8859_4 • encodings.iso8859_5 • encodings.iso8859_6 • encodings.iso8859_7 • encodings.iso8859_8 • encodings.iso8859_9 • encodings.johab • encodings.koi8_r • encodings.koi8_t • encodings.koi8_u • encodings.kz1048 • encodings.latin_1 • encodings.mac_arabic • encodings.mac_centeuro • encodings.mac_croatian • encodings.mac_cyrillic • encodings.mac_farsi • encodings.mac_greek • encodings.mac_iceland • encodings.mac_latin2 • encodings.mac_roman • encodings.mac_romanian • encodings.mac_turkish • encodings.mbcs • encodings.oem • encodings.palmos • encodings.ptcp154 • encodings.punycode • encodings.quopri_codec • encodings.raw_unicode_escape • encodings.rot_13 • encodings.shift_jis • encodings.shift_jis_2004 • encodings.shift_jisx0213 • encodings.tis_620 • encodings.undefined • encodings.unicode_escape • encodings.unicode_internal • encodings.utf_16 • encodings.utf_16_be • encodings.utf_16_le • encodings.utf_32 • encodings.utf_32_be • encodings.utf_32_le • encodings.utf_7 • encodings.utf_8 • encodings.utf_8_sig • encodings.uu_codec • encodings.zlib_codec • enum • functools • future • future.standard_library • heapq • io • keyword • linecache • locale • operator • pyi_rth__tkinter.py • pyi_rth_multiprocessing.py • pyi_rth_win32api.py • re • reprlib • rocket_units • rocketunits.rocket_units • sre_compile • sre_constants • sre_parse • tkinter • tkinter.filedialog • tkinter.ttk • traceback • types • warnings • weakref
`'java.lang'` MissingModule
imported by: platform • xml.sax._exceptions
`'org.python'` MissingModule
imported by: pickle • xml.sax
`__builtin__` MissingModule
imported by: future.builtins.misc • future.utils
`__future__` SourceModule
imported by: codeop • doctest • future.backports • future.backports.datetime • future.backports.email • future.backports.email._encoded_words • future.backports.email._parseaddr • future.backports.email._policybase • future.backports.email.base64mime • future.backports.email.charset • future.backports.email.encoders • future.backports.email.errors • future.backports.email.feedparser • future.backports.email.generator • future.backports.email.header • future.backports.email.iterators • future.backports.email.message • future.backports.email.parser • future.backports.email.quoprimime • future.backports.email.utils • future.backports.http.client • future.backports.http.cookiejar • future.backports.misc • future.backports.urllib.error • future.backports.urllib.parse • future.backports.urllib.request • future.backports.urllib.response • future.backports.urllib.robotparser • future.builtins.iterators • future.builtins.newsuper • future.moves • future.moves.dbm • future.moves.dbm.dumb • future.moves.dbm.gnu • future.moves.dbm.ndbm • future.moves.test • future.moves.test.support • future.standard_library • future.types • future.types.newint • future.types.newrange • tk_rocket_units.py
`_abc` (builtin module)
imported by: abc
`_ast` (builtin module)
imported by: ast
`_bisect` (builtin module)
imported by: bisect
`_blake2` (builtin module)
imported by: hashlib
`_bootlocale` SourceModule
imports: _locale • locale • sys
imported by: locale • tk_rocket_units.py
`_bz2` `d:\python37_64\DLLs\_bz2.pyd`
imported by: bz2
`_codecs` (builtin module)
imported by: codecs
`_codecs_cn` (builtin module)
imported by: encodings.gb18030 • encodings.gb2312 • encodings.gbk • encodings.hz
`_codecs_hk` (builtin module)
imported by: encodings.big5hkscs
`_codecs_iso2022` (builtin module)
imported by: encodings.iso2022_jp • encodings.iso2022_jp_1 • encodings.iso2022_jp_2 • encodings.iso2022_jp_2004 • encodings.iso2022_jp_3 • encodings.iso2022_jp_ext • encodings.iso2022_kr
`_codecs_jp` (builtin module)
imported by: encodings.cp932 • encodings.euc_jis_2004 • encodings.euc_jisx0213 • encodings.euc_jp • encodings.shift_jis • encodings.shift_jis_2004 • encodings.shift_jisx0213
`_codecs_kr` (builtin module)
imported by: encodings.cp949 • encodings.euc_kr • encodings.johab
`_codecs_tw` (builtin module)
imported by: encodings.big5 • encodings.cp950
`_collections` (builtin module)
imported by: collections • enum • threading
`_collections_abc` SourceModule
imports: abc • sys
imported by: collections • collections.abc • contextlib • locale • os • random • tk_rocket_units.py • types • weakref
`_compat_pickle` SourceModule
imported by: _pickle • pickle
`_compression` SourceModule
imports: io
imported by: bz2 • gzip • lzma
`_contextvars` (builtin module)
imported by: contextvars
`_ctypes` `d:\python37_64\DLLs\_ctypes.pyd`
imported by: ctypes
`_datetime` (builtin module)
imports: _strptime • time
imported by: datetime • future.backports.datetime
`_dbm` MissingModule
imported by: dbm.ndbm
`_decimal` `d:\python37_64\DLLs\_decimal.pyd`
imported by: decimal
`_dummy_thread` SourceModule
imports: time • traceback
imported by: dummy_threading • future.backports.misc
`_dummy_threading` MissingModule
imported by: dummy_threading
`_elementtree` `d:\python37_64\DLLs\_elementtree.pyd`
imports: pyexpat • xml.etree.ElementInclude • xml.etree.ElementPath • xml.etree.ElementTree • xml.etree.cElementTree
imported by: xml.etree.ElementTree
`_frozen_importlib` ExcludedModule
imported by: importlib • importlib.abc
`_frozen_importlib_external` MissingModule
imported by: importlib • importlib._bootstrap • importlib.abc
`_functools` (builtin module)
imported by: functools
`_gdbm` MissingModule
imported by: dbm.gnu
`_hashlib` `d:\python37_64\DLLs\_hashlib.pyd`
imported by: hashlib • hmac
`_heapq` (builtin module)
imported by: heapq
`_imp` (builtin module)
imported by: distutils.sysconfig • imp • importlib • importlib.machinery • importlib.util
`_io` (builtin module)
imported by: io
`_locale` (builtin module)
imported by: _bootlocale • locale • re
`_lzma` `d:\python37_64\DLLs\_lzma.pyd`
imported by: lzma
`_md5` (builtin module)
imported by: hashlib
`_multibytecodec` (builtin module)
imported by: encodings.big5 • encodings.big5hkscs • encodings.cp932 • encodings.cp949 • encodings.cp950 • encodings.euc_jis_2004 • encodings.euc_jisx0213 • encodings.euc_jp • encodings.euc_kr • encodings.gb18030 • encodings.gb2312 • encodings.gbk • encodings.hz • encodings.iso2022_jp • encodings.iso2022_jp_1 • encodings.iso2022_jp_2 • encodings.iso2022_jp_2004 • encodings.iso2022_jp_3 • encodings.iso2022_jp_ext • encodings.iso2022_kr • encodings.johab • encodings.shift_jis • encodings.shift_jis_2004 • encodings.shift_jisx0213
`_multiprocessing` `d:\python37_64\DLLs\_multiprocessing.pyd`
imported by: multiprocessing.connection • multiprocessing.queues • multiprocessing.semaphore_tracker • multiprocessing.synchronize
`_opcode` (builtin module)
imported by: opcode
`_operator` (builtin module)
imported by: hmac • operator
`_osx_support` SourceModule
imports: contextlib • distutils • distutils.log • os • re • sys • tempfile
imported by: distutils.sysconfig • distutils.util • sysconfig
`_pickle` (builtin module)
imports: _compat_pickle • codecs • copyreg
imported by: pickle
`_posixsubprocess` MissingModule
imports: gc
imported by: multiprocessing.util • subprocess
`_py_abc` SourceModule
imports: _weakrefset
imported by: abc
`_pydecimal` SourceModule
imports: collections • contextvars • itertools • locale • math • numbers • re • sys
imported by: decimal
`_queue` `d:\python37_64\DLLs\_queue.pyd`
imported by: queue
`_random` (builtin module)
imported by: random
`_scproxy` MissingModule
imported by: future.backports.urllib.request • urllib.request
`_sha1` (builtin module)
imported by: hashlib
`_sha256` (builtin module)
imported by: hashlib
`_sha3` (builtin module)
imported by: hashlib
`_sha512` (builtin module)
imported by: hashlib
`_signal` (builtin module)
imported by: signal
`_socket` `d:\python37_64\DLLs\_socket.pyd`
imported by: socket
`_sre` (builtin module)
imports: copy • re
imported by: sre_compile • sre_constants
`_ssl` `d:\python37_64\DLLs\_ssl.pyd`
imports: socket
imported by: ssl
`_stat` (builtin module)
imported by: stat
`_string` (builtin module)
imported by: string
`_strptime` SourceModule
imports: _thread • calendar • datetime • locale • re • time
imported by: _datetime • datetime • future.backports.datetime • time
`_struct` (builtin module)
imported by: struct
`_testcapi` `d:\python37_64\DLLs\_testcapi.pyd`
imported by: test.support
`_thread` (builtin module)
imported by: _strptime • functools • future.backports.misc • reprlib • tempfile • test.support • threading
`_threading_local` SourceModule
imports: contextlib • threading • weakref
imported by: threading
`_tkinter` `d:\python37_64\DLLs\_tkinter.pyd`
imported by: tkinter
`_tracemalloc` (builtin module)
imported by: tracemalloc
`_warnings` (builtin module)
imported by: warnings
`_weakref` (builtin module)
imported by: _weakrefset • collections • future.backports.misc • weakref • xml.sax.expatreader
`_weakrefset` SourceModule
imports: _weakref
imported by: _py_abc • multiprocessing.process • threading • tk_rocket_units.py • weakref
`_win32sysloader` `d:\python37_64\lib\site-packages\win32\_win32sysloader.pyd`
imported by: pywintypes
`_winapi` (builtin module)
imported by: encodings • multiprocessing.connection • multiprocessing.heap • multiprocessing.popen_spawn_win32 • multiprocessing.reduction • subprocess
`_winreg` MissingModule
imported by: platform
`abc` SourceModule
imports: _abc • _py_abc
imported by: _collections_abc • contextlib • email._policybase • functools • future.backports.email._policybase • importlib.abc • inspect • io • multiprocessing.reduction • numbers • os • selectors • tk_rocket_units.py • typing
`anydbm` MissingModule
imports: dbhash • dbm • dumbdbm • gdbm • whichdb
imported by: future.moves.dbm
`argparse` SourceModule
imports: copy • gettext • os • re • sys • textwrap • warnings
imported by: calendar • code • dis • doctest • http.server • inspect • nntplib • tarfile • tokenize • unittest.main • zipfile
`array` (builtin module)
imported by: future.backports.http.client • future.backports.urllib.request • multiprocessing.dummy • multiprocessing.managers • multiprocessing.reduction
`ast` SourceModule
imports: _ast • collections • inspect
imported by: dbm.dumb • inspect
`atexit` (builtin module)
imported by: logging • multiprocessing.util • weakref
`base64` SourceModule
imports: binascii • getopt • re • struct • sys • warnings
imported by: email._encoded_words • email.base64mime • email.encoders • encodings.base64_codec • future.backports.email._encoded_words • future.backports.email.base64mime • future.backports.email.encoders • future.backports.email.message • future.backports.email.utils • future.backports.urllib.request • http.server • logging.handlers • smtplib • ssl • urllib.request • xmlrpc.client
`bdb` SourceModule
imports: fnmatch • inspect • linecache • os • reprlib • sys
imported by: pdb
`binascii` (builtin module)
imported by: base64 • email._encoded_words • email.base64mime • email.contentmanager • email.header • encodings.hex_codec • encodings.uu_codec • future.backports.email._encoded_words • future.backports.email.base64mime • future.backports.email.header • future.backports.email.message • http.server • plistlib • quopri • uu • zipfile
`bisect` SourceModule
imports: _bisect
imported by: future.backports.urllib.request • multiprocessing.heap • random • urllib.request
`builtins` (builtin module)
imported by: bz2 • codecs • doctest • future.builtins • future.builtins.iterators • future.builtins.misc • future.types • future.utils • gettext • gzip • inspect • locale • lzma • operator • pydoc • reprlib • subprocess • tarfile • tk_rocket_units.py • tokenize
`bz2` SourceModule
imports: _bz2 • _compression • builtins • io • os • threading • warnings
imported by: encodings.bz2_codec • shutil • tarfile • test.support • zipfile
`calendar` SourceModule
imports: argparse • datetime • itertools • locale • sys
imported by: _strptime • email._parseaddr • future.backports.email._parseaddr • future.backports.http.cookiejar • http.cookiejar • ssl
`cmd` SourceModule
imports: readline • string • sys
imported by: pdb
`code` SourceModule
imports: argparse • codeop • readline • sys • traceback
imported by: pdb
`codecs` SourceModule
imports: _codecs • builtins • encodings • sys
imported by: _pickle • encodings • encodings.ascii • encodings.base64_codec • encodings.big5 • encodings.big5hkscs • encodings.bz2_codec • encodings.charmap • encodings.cp037 • encodings.cp1006 • encodings.cp1026 • encodings.cp1125 • encodings.cp1140 • encodings.cp1250 • encodings.cp1251 • encodings.cp1252 • encodings.cp1253 • encodings.cp1254 • encodings.cp1255 • encodings.cp1256 • encodings.cp1257 • encodings.cp1258 • encodings.cp273 • encodings.cp424 • encodings.cp437 • encodings.cp500 • encodings.cp65001 • encodings.cp720 • encodings.cp737 • encodings.cp775 • encodings.cp850 • encodings.cp852 • encodings.cp855 • encodings.cp856 • encodings.cp857 • encodings.cp858 • encodings.cp860 • encodings.cp861 • encodings.cp862 • encodings.cp863 • encodings.cp864 • encodings.cp865 • encodings.cp866 • encodings.cp869 • encodings.cp874 • encodings.cp875 • encodings.cp932 • encodings.cp949 • encodings.cp950 • encodings.euc_jis_2004 • encodings.euc_jisx0213 • encodings.euc_jp • encodings.euc_kr • encodings.gb18030 • encodings.gb2312 • encodings.gbk • encodings.hex_codec • encodings.hp_roman8 • encodings.hz • encodings.idna • encodings.iso2022_jp • encodings.iso2022_jp_1 • encodings.iso2022_jp_2 • encodings.iso2022_jp_2004 • encodings.iso2022_jp_3 • encodings.iso2022_jp_ext • encodings.iso2022_kr • encodings.iso8859_1 • encodings.iso8859_10 • encodings.iso8859_11 • encodings.iso8859_13 • encodings.iso8859_14 • encodings.iso8859_15 • encodings.iso8859_16 • encodings.iso8859_2 • encodings.iso8859_3 • encodings.iso8859_4 • encodings.iso8859_5 • encodings.iso8859_6 • encodings.iso8859_7 • encodings.iso8859_8 • encodings.iso8859_9 • encodings.johab • encodings.koi8_r • encodings.koi8_t • encodings.koi8_u • encodings.kz1048 • encodings.latin_1 • encodings.mac_arabic • encodings.mac_centeuro • encodings.mac_croatian • encodings.mac_cyrillic • encodings.mac_farsi • encodings.mac_greek • encodings.mac_iceland • encodings.mac_latin2 • encodings.mac_roman • encodings.mac_romanian • encodings.mac_turkish • encodings.mbcs • encodings.oem • encodings.palmos • encodings.ptcp154 • encodings.punycode • encodings.quopri_codec • encodings.raw_unicode_escape • encodings.rot_13 • encodings.shift_jis • encodings.shift_jis_2004 • encodings.shift_jisx0213 • encodings.tis_620 • encodings.undefined • encodings.unicode_escape • encodings.unicode_internal • encodings.utf_16 • encodings.utf_16_be • encodings.utf_16_le • encodings.utf_32 • encodings.utf_32_be • encodings.utf_32_le • encodings.utf_7 • encodings.utf_8 • encodings.utf_8_sig • encodings.uu_codec • encodings.zlib_codec • future.utils.surrogateescape • lib2to3.pgen2.driver • lib2to3.pgen2.tokenize • pickle • plistlib • tk_rocket_units.py • tokenize • xml.sax.saxutils
`codeop` SourceModule
imports: __future__
imported by: code
`collections` Package
imports: _collections • _collections_abc • _weakref • collections.Iterable • collections.Iterator • collections.Mapping • collections.MutableMapping • collections.Sequence • copy • heapq • itertools • keyword • operator • reprlib • sys • warnings
imported by: _pydecimal • ast • collections.abc • contextlib • difflib • dis • doctest • email._header_value_parser • email.feedparser • enum • functools • future.backports.http.client • future.backports.misc • future.backports.urllib.parse • future.backports.urllib.request • future.types.newbytes • future.types.newint • future.types.newrange • future.types.newstr • inspect • lib2to3.btm_matcher • lib2to3.pgen2.grammar • lib2to3.refactor • multiprocessing.pool • multiprocessing.queues • nntplib • pkgutil • platform • pprint • pydoc • queue • sched • selectors • shlex • shutil • ssl • string • test.support.script_helper • threading • tk_rocket_units.py • tokenize • traceback • typing • unittest.case • unittest.util • urllib.parse • xml.etree.ElementTree
`collections.Iterable` MissingModule
imported by: collections • future.types.newbytes • future.types.newstr
`collections.Iterator` MissingModule
imported by: collections • future.types.newrange
`collections.Mapping` MissingModule
imported by: collections • future.backports.misc
`collections.MutableMapping` MissingModule
imported by: collections • future.backports.misc
`collections.Sequence` MissingModule
imported by: collections • future.types.newrange
`collections.abc` SourceModule
imports: _collections_abc • collections
imported by: dbm.dumb • http.client • inspect • logging • selectors • test.support • tk_rocket_units.py • tracemalloc • typing • xml.etree.ElementTree
`contextlib` SourceModule
imports: _collections_abc • abc • collections • functools • sys
imported by: _osx_support • _threading_local • future.backports.urllib.request • future.standard_library • getpass • importlib.util • plistlib • test.support • test.test_support • typing • unittest.case • urllib.request • xml.etree.ElementTree
`contextvars` SourceModule
imports: _contextvars
imported by: _pydecimal
`copy` SourceModule
imports: copyreg • org • types • weakref
imported by: _sre • argparse • collections • email.generator • future.backports.http.cookiejar • future.standard_library • future.types.newbytes • future.types.newlist • future.utils • gettext • http.cookiejar • http.server • logging.handlers • smtplib • tarfile • weakref • webbrowser • xml.etree.ElementInclude
`copyreg` SourceModule
imported by: _pickle • copy • multiprocessing.reduction • pickle • re • tk_rocket_units.py
`ctypes` Package
imports: _ctypes • ctypes._endian • os • struct • sys
imported by: ctypes._aix • ctypes._endian • ctypes.macholib • ctypes.util • ctypes.wintypes • multiprocessing.sharedctypes • test.support
`ctypes._aix` SourceModule
imports: ctypes • os • re • subprocess • sys
imported by: ctypes.util
`ctypes._endian` SourceModule
imports: ctypes • sys
imported by: ctypes
`ctypes.macholib` Package
imports: ctypes
imported by: ctypes.macholib.dyld • ctypes.macholib.dylib • ctypes.macholib.framework
`ctypes.macholib.dyld` SourceModule
imports: ctypes.macholib • ctypes.macholib.dylib • ctypes.macholib.framework • itertools • os
imported by: ctypes.util
`ctypes.macholib.dylib` SourceModule
imports: ctypes.macholib • re
imported by: ctypes.macholib.dyld
`ctypes.macholib.framework` SourceModule
imports: ctypes.macholib • re
imported by: ctypes.macholib.dyld
`ctypes.util` SourceModule
imports: ctypes • ctypes._aix • ctypes.macholib.dyld • importlib.machinery • os • re • shutil • struct • subprocess • sys • tempfile
imported by: test.support
`ctypes.wintypes` SourceModule
imports: ctypes
imported by: test.support
`datetime` SourceModule
imports: _datetime • _strptime • math • sys • time
imported by: _strptime • calendar • email.utils • future.backports.http.cookiejar • http.cookiejar • http.server • nntplib • plistlib • smtplib • test.support • test.support.testresult • xmlrpc.client
`dbhash` MissingModule
imported by: anydbm
`dbm` Package
imports: dbm • dbm.ndbm • io • os • struct • sys
imported by: anydbm • dbm • dbm.dumb • dbm.gnu • dbm.ndbm • future.moves.dbm • future.moves.dbm.ndbm • future.standard_library
`dbm.dumb` SourceModule
imports: ast • collections.abc • dbm • io • os • warnings
imported by: future.moves.dbm.dumb
`dbm.gnu` SourceModule
imports: _gdbm • dbm
imported by: future.moves.dbm.gnu
`dbm.ndbm` SourceModule
imports: _dbm • dbm
imported by: dbm • future.moves.dbm • future.moves.dbm.ndbm
`decimal` SourceModule
imports: _decimal • _pydecimal
imported by: future.builtins.newround • tk_rocket_units.py • xmlrpc.client
`difflib` SourceModule
imports: collections • difflib • heapq • re
imported by: difflib • doctest • unittest.case
`dis` SourceModule
imports: argparse • collections • io • opcode • sys • types
imported by: inspect • pdb
`distutils` Package
imports: distutils.ccompiler • distutils.log • distutils.sysconfig • sys
imported by: _osx_support • distutils.ccompiler • distutils.debug • distutils.dep_util • distutils.dir_util • distutils.errors • distutils.fancy_getopt • distutils.file_util • distutils.filelist • distutils.log • distutils.spawn • distutils.sysconfig • distutils.text_file • distutils.util • test.support
`distutils.ccompiler` SourceModule
imports: distutils • distutils.debug • distutils.dep_util • distutils.dir_util • distutils.errors • distutils.fancy_getopt • distutils.file_util • distutils.log • distutils.spawn • distutils.util • os • re • sys • tempfile
imported by: distutils • test.support
`distutils.debug` SourceModule
imports: distutils • os
imported by: distutils.ccompiler • distutils.filelist • distutils.spawn
`distutils.dep_util` SourceModule
imports: distutils • distutils.errors • os • stat
imported by: distutils.ccompiler • distutils.file_util • distutils.util
`distutils.dir_util` SourceModule
imports: distutils • distutils.errors • distutils.file_util • distutils.log • errno • os
imported by: distutils.ccompiler • distutils.util
`distutils.errors` SourceModule
imports: distutils
imported by: distutils.ccompiler • distutils.dep_util • distutils.dir_util • distutils.fancy_getopt • distutils.file_util • distutils.filelist • distutils.spawn • distutils.sysconfig • distutils.util
`distutils.fancy_getopt` SourceModule
imports: distutils • distutils.errors • getopt • re • string • sys
imported by: distutils.ccompiler
`distutils.file_util` SourceModule
imports: distutils • distutils.dep_util • distutils.errors • distutils.log • errno • ntpath • os • stat
imported by: distutils.ccompiler • distutils.dir_util • distutils.util
`distutils.filelist` SourceModule
imports: distutils • distutils.debug • distutils.errors • distutils.log • distutils.util • fnmatch • functools • os • re
imported by: distutils.util
`distutils.log` SourceModule
imports: distutils • sys
imported by: _osx_support • distutils • distutils.ccompiler • distutils.dir_util • distutils.file_util • distutils.filelist • distutils.spawn • distutils.util
`distutils.spawn` SourceModule
imports: distutils • distutils.debug • distutils.errors • distutils.log • distutils.sysconfig • os • sys
imported by: distutils.ccompiler • distutils.util • test.support
`distutils.sysconfig` SourceModule
imports: _imp • _osx_support • distutils • distutils.errors • distutils.text_file • os • re • sys • warnings
imported by: distutils • distutils.spawn • distutils.util • pywintypes • test.support
`distutils.text_file` SourceModule
imports: distutils • io • sys
imported by: distutils.sysconfig
`distutils.util` SourceModule
imports: _osx_support • distutils • distutils.dep_util • distutils.dir_util • distutils.errors • distutils.file_util • distutils.filelist • distutils.log • distutils.spawn • distutils.sysconfig • importlib.util • os • pwd • py_compile • re • string • subprocess • sys • tempfile
imported by: distutils.ccompiler • distutils.filelist
`doctest` SourceModule
imports: __future__ • argparse • builtins • collections • difflib • inspect • io • linecache • os • pdb • re • sys • traceback • unittest
imported by: pickle • test.support
`dumbdbm` MissingModule
imported by: anydbm • future.moves.dbm.dumb
`dummy_thread` MissingModule
imported by: future.backports.misc
`dummy_threading` SourceModule
imports: _dummy_thread • _dummy_threading • sys • threading
imported by: future.backports.http.cookiejar
`email` Package
imports: email._header_value_parser • email.charset • email.errors • email.header • email.parser
imported by: email._encoded_words • email._header_value_parser • email._parseaddr • email._policybase • email.base64mime • email.charset • email.contentmanager • email.encoders • email.errors • email.feedparser • email.generator • email.header • email.headerregistry • email.iterators • email.message • email.parser • email.policy • email.quoprimime • email.utils • future.standard_library • urllib.request
`email._encoded_words` SourceModule
imports: base64 • binascii • email • email.errors • functools • re • string
imported by: email._header_value_parser • email.message
`email._header_value_parser` SourceModule
imports: collections • email • email._encoded_words • email.errors • email.utils • operator • re • string • sys • urllib
imported by: email • email.headerregistry
`email._parseaddr` SourceModule
imports: calendar • email • time
imported by: email.utils
`email._policybase` SourceModule
imports: abc • email • email.charset • email.header • email.utils
imported by: email.feedparser • email.message • email.parser • email.policy
`email.base64mime` SourceModule
imports: base64 • binascii • email
imported by: email.charset • email.header • smtplib
`email.charset` SourceModule
imports: email • email.base64mime • email.encoders • email.errors • email.quoprimime • functools
imported by: email • email._policybase • email.contentmanager • email.header • email.message • email.utils
`email.contentmanager` SourceModule
imports: binascii • email • email.charset • email.errors • email.message • email.quoprimime
imported by: email.policy
`email.encoders` SourceModule
imports: base64 • email • quopri
imported by: email.charset
`email.errors` SourceModule
imports: email
imported by: email • email._encoded_words • email._header_value_parser • email.charset • email.contentmanager • email.feedparser • email.header • email.headerregistry • email.message
`email.feedparser` SourceModule
imports: collections • email • email._policybase • email.errors • email.message • io • re
imported by: email.parser
`email.generator` SourceModule
imports: copy • email • email.utils • io • random • re • sys • time
imported by: email.message • smtplib
`email.header` SourceModule
imports: binascii • email • email.base64mime • email.charset • email.errors • email.quoprimime • re
imported by: email • email._policybase • nntplib
`email.headerregistry` SourceModule
imports: email • email._header_value_parser • email.errors • email.utils • types
imported by: email.policy
`email.iterators` SourceModule
imports: email • io • sys
imported by: email.message
`email.message` SourceModule
imports: email • email._encoded_words • email._policybase • email.charset • email.errors • email.generator • email.iterators • email.policy • email.utils • io • quopri • re • uu
imported by: email.contentmanager • email.feedparser • email.policy • http.client • logging.handlers • pydoc • smtplib
`email.parser` SourceModule
imports: email • email._policybase • email.feedparser • io
imported by: email • http.client
`email.policy` SourceModule
imports: email • email._policybase • email.contentmanager • email.headerregistry • email.message • email.utils • re • sys
imported by: email.message
`email.quoprimime` SourceModule
imports: email • re • string
imported by: email.charset • email.contentmanager • email.header
`email.utils` SourceModule
imports: datetime • email • email._parseaddr • email.charset • os • random • re • socket • time • urllib.parse
imported by: email._header_value_parser • email._policybase • email.generator • email.headerregistry • email.message • email.policy • http.server • logging.handlers • smtplib • urllib.request
`encodings` Package
imports: _winapi • codecs • encodings • encodings.aliases • encodings.ascii • encodings.base64_codec • encodings.big5 • encodings.big5hkscs • encodings.bz2_codec • encodings.charmap • encodings.cp037 • encodings.cp1006 • encodings.cp1026 • encodings.cp1125 • encodings.cp1140 • encodings.cp1250 • encodings.cp1251 • encodings.cp1252 • encodings.cp1253 • encodings.cp1254 • encodings.cp1255 • encodings.cp1256 • encodings.cp1257 • encodings.cp1258 • encodings.cp273 • encodings.cp424 • encodings.cp437 • encodings.cp500 • encodings.cp65001 • encodings.cp720 • encodings.cp737 • encodings.cp775 • encodings.cp850 • encodings.cp852 • encodings.cp855 • encodings.cp856 • encodings.cp857 • encodings.cp858 • encodings.cp860 • encodings.cp861 • encodings.cp862 • encodings.cp863 • encodings.cp864 • encodings.cp865 • encodings.cp866 • encodings.cp869 • encodings.cp874 • encodings.cp875 • encodings.cp932 • encodings.cp949 • encodings.cp950 • encodings.euc_jis_2004 • encodings.euc_jisx0213 • encodings.euc_jp • encodings.euc_kr • encodings.gb18030 • encodings.gb2312 • encodings.gbk • encodings.hex_codec • encodings.hp_roman8 • encodings.hz • encodings.idna • encodings.iso2022_jp • encodings.iso2022_jp_1 • encodings.iso2022_jp_2 • encodings.iso2022_jp_2004 • encodings.iso2022_jp_3 • encodings.iso2022_jp_ext • encodings.iso2022_kr • encodings.iso8859_1 • encodings.iso8859_10 • encodings.iso8859_11 • encodings.iso8859_13 • encodings.iso8859_14 • encodings.iso8859_15 • encodings.iso8859_16 • encodings.iso8859_2 • encodings.iso8859_3 • encodings.iso8859_4 • encodings.iso8859_5 • encodings.iso8859_6 • encodings.iso8859_7 • encodings.iso8859_8 • encodings.iso8859_9 • encodings.johab • encodings.koi8_r • encodings.koi8_t • encodings.koi8_u • encodings.kz1048 • encodings.latin_1 • encodings.mac_arabic • encodings.mac_centeuro • encodings.mac_croatian • encodings.mac_cyrillic • encodings.mac_farsi • encodings.mac_greek • encodings.mac_iceland • encodings.mac_latin2 • encodings.mac_roman • encodings.mac_romanian • encodings.mac_turkish • encodings.mbcs • encodings.oem • encodings.palmos • encodings.ptcp154 • encodings.punycode • encodings.quopri_codec • encodings.raw_unicode_escape • encodings.rot_13 • encodings.shift_jis • encodings.shift_jis_2004 • encodings.shift_jisx0213 • encodings.tis_620 • encodings.undefined • encodings.unicode_escape • encodings.unicode_internal • encodings.utf_16 • encodings.utf_16_be • encodings.utf_16_le • encodings.utf_32 • encodings.utf_32_be • encodings.utf_32_le • encodings.utf_7 • encodings.utf_8 • encodings.utf_8_sig • encodings.uu_codec • encodings.zlib_codec • sys
imported by: codecs • encodings • encodings.aliases • encodings.ascii • encodings.base64_codec • encodings.big5 • encodings.big5hkscs • encodings.bz2_codec • encodings.charmap • encodings.cp037 • encodings.cp1006 • encodings.cp1026 • encodings.cp1125 • encodings.cp1140 • encodings.cp1250 • encodings.cp1251 • encodings.cp1252 • encodings.cp1253 • encodings.cp1254 • encodings.cp1255 • encodings.cp1256 • encodings.cp1257 • encodings.cp1258 • encodings.cp273 • encodings.cp424 • encodings.cp437 • encodings.cp500 • encodings.cp65001 • encodings.cp720 • encodings.cp737 • encodings.cp775 • encodings.cp850 • encodings.cp852 • encodings.cp855 • encodings.cp856 • encodings.cp857 • encodings.cp858 • encodings.cp860 • encodings.cp861 • encodings.cp862 • encodings.cp863 • encodings.cp864 • encodings.cp865 • encodings.cp866 • encodings.cp869 • encodings.cp874 • encodings.cp875 • encodings.cp932 • encodings.cp949 • encodings.cp950 • encodings.euc_jis_2004 • encodings.euc_jisx0213 • encodings.euc_jp • encodings.euc_kr • encodings.gb18030 • encodings.gb2312 • encodings.gbk • encodings.hex_codec • encodings.hp_roman8 • encodings.hz • encodings.idna • encodings.iso2022_jp • encodings.iso2022_jp_1 • encodings.iso2022_jp_2 • encodings.iso2022_jp_2004 • encodings.iso2022_jp_3 • encodings.iso2022_jp_ext • encodings.iso2022_kr • encodings.iso8859_1 • encodings.iso8859_10 • encodings.iso8859_11 • encodings.iso8859_13 • encodings.iso8859_14 • encodings.iso8859_15 • encodings.iso8859_16 • encodings.iso8859_2 • encodings.iso8859_3 • encodings.iso8859_4 • encodings.iso8859_5 • encodings.iso8859_6 • encodings.iso8859_7 • encodings.iso8859_8 • encodings.iso8859_9 • encodings.johab • encodings.koi8_r • encodings.koi8_t • encodings.koi8_u • encodings.kz1048 • encodings.latin_1 • encodings.mac_arabic • encodings.mac_centeuro • encodings.mac_croatian • encodings.mac_cyrillic • encodings.mac_farsi • encodings.mac_greek • encodings.mac_iceland • encodings.mac_latin2 • encodings.mac_roman • encodings.mac_romanian • encodings.mac_turkish • encodings.mbcs • encodings.oem • encodings.palmos • encodings.ptcp154 • encodings.punycode • encodings.quopri_codec • encodings.raw_unicode_escape • encodings.rot_13 • encodings.shift_jis • encodings.shift_jis_2004 • encodings.shift_jisx0213 • encodings.tis_620 • encodings.undefined • encodings.unicode_escape • encodings.unicode_internal • encodings.utf_16 • encodings.utf_16_be • encodings.utf_16_le • encodings.utf_32 • encodings.utf_32_be • encodings.utf_32_le • encodings.utf_7 • encodings.utf_8 • encodings.utf_8_sig • encodings.uu_codec • encodings.zlib_codec • locale • tk_rocket_units.py
`encodings.aliases` SourceModule
imports: encodings
imported by: encodings • locale • tk_rocket_units.py
`encodings.ascii` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.base64_codec` SourceModule
imports: base64 • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.big5` SourceModule
imports: _codecs_tw • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.big5hkscs` SourceModule
imports: _codecs_hk • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.bz2_codec` SourceModule
imports: bz2 • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.charmap` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp037` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp1006` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp1026` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp1125` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp1140` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp1250` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp1251` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp1252` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp1253` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp1254` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp1255` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp1256` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp1257` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp1258` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp273` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp424` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp437` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp500` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp65001` SourceModule
imports: codecs • encodings • functools
imported by: encodings • tk_rocket_units.py
`encodings.cp720` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp737` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp775` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp850` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp852` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp855` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp856` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp857` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp858` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp860` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp861` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp862` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp863` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp864` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp865` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp866` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp869` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp874` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp875` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp932` SourceModule
imports: _codecs_jp • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp949` SourceModule
imports: _codecs_kr • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.cp950` SourceModule
imports: _codecs_tw • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.euc_jis_2004` SourceModule
imports: _codecs_jp • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.euc_jisx0213` SourceModule
imports: _codecs_jp • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.euc_jp` SourceModule
imports: _codecs_jp • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.euc_kr` SourceModule
imports: _codecs_kr • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.gb18030` SourceModule
imports: _codecs_cn • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.gb2312` SourceModule
imports: _codecs_cn • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.gbk` SourceModule
imports: _codecs_cn • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.hex_codec` SourceModule
imports: binascii • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.hp_roman8` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.hz` SourceModule
imports: _codecs_cn • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.idna` SourceModule
imports: codecs • encodings • re • stringprep • unicodedata
imported by: encodings • tk_rocket_units.py
`encodings.iso2022_jp` SourceModule
imports: _codecs_iso2022 • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso2022_jp_1` SourceModule
imports: _codecs_iso2022 • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso2022_jp_2` SourceModule
imports: _codecs_iso2022 • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso2022_jp_2004` SourceModule
imports: _codecs_iso2022 • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso2022_jp_3` SourceModule
imports: _codecs_iso2022 • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso2022_jp_ext` SourceModule
imports: _codecs_iso2022 • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso2022_kr` SourceModule
imports: _codecs_iso2022 • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso8859_1` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso8859_10` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso8859_11` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso8859_13` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso8859_14` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso8859_15` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso8859_16` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso8859_2` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso8859_3` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso8859_4` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso8859_5` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso8859_6` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso8859_7` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso8859_8` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.iso8859_9` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.johab` SourceModule
imports: _codecs_kr • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.koi8_r` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.koi8_t` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.koi8_u` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.kz1048` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.latin_1` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.mac_arabic` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.mac_centeuro` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.mac_croatian` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.mac_cyrillic` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.mac_farsi` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.mac_greek` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.mac_iceland` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.mac_latin2` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.mac_roman` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.mac_romanian` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.mac_turkish` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.mbcs` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.oem` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.palmos` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.ptcp154` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.punycode` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.quopri_codec` SourceModule
imports: codecs • encodings • io • quopri
imported by: encodings • tk_rocket_units.py
`encodings.raw_unicode_escape` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.rot_13` SourceModule
imports: codecs • encodings • sys
imported by: encodings • tk_rocket_units.py
`encodings.shift_jis` SourceModule
imports: _codecs_jp • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.shift_jis_2004` SourceModule
imports: _codecs_jp • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.shift_jisx0213` SourceModule
imports: _codecs_jp • _multibytecodec • codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.tis_620` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.undefined` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.unicode_escape` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.unicode_internal` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.utf_16` SourceModule
imports: codecs • encodings • sys
imported by: encodings • tk_rocket_units.py
`encodings.utf_16_be` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.utf_16_le` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.utf_32` SourceModule
imports: codecs • encodings • sys
imported by: encodings • tk_rocket_units.py
`encodings.utf_32_be` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.utf_32_le` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.utf_7` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.utf_8` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.utf_8_sig` SourceModule
imports: codecs • encodings
imported by: encodings • tk_rocket_units.py
`encodings.uu_codec` SourceModule
imports: binascii • codecs • encodings • io
imported by: encodings • tk_rocket_units.py
`encodings.zlib_codec` SourceModule
imports: codecs • encodings • zlib
imported by: encodings • tk_rocket_units.py
`enum` SourceModule
imports: _collections • collections • sys • types • warnings
imported by: http • inspect • plistlib • py_compile • re • signal • socket • ssl • tk_rocket_units.py • tkinter
`errno` (builtin module)
imported by: distutils.dir_util • distutils.file_util • gettext • gzip • multiprocessing.forkserver • multiprocessing.queues • shutil • socket • ssl • subprocess • tempfile • test.support • test.test_support • xmlrpc.client
`faulthandler` (builtin module)
imported by: test.support
`fnmatch` SourceModule
imports: functools • os • posixpath • re
imported by: bdb • distutils.filelist • future.backports.urllib.request • glob • shutil • test.support • tkinter.filedialog • tracemalloc • unittest.loader • urllib.request
`ftplib` SourceModule
imports: netrc • re • socket • ssl • sys • warnings
imported by: future.backports.urllib.request • urllib.request
`functools` SourceModule
imports: _functools • _thread • abc • collections • reprlib • types • typing • weakref
imported by: contextlib • distutils.filelist • email._encoded_words • email.charset • encodings.cp65001 • fnmatch • future.backports.email._encoded_words • future.backports.email.charset • future.backports.misc • future.types • future.utils • http.server • importlib.util • inspect • linecache • locale • multiprocessing.reduction • operator • pickle • pkgutil • re • signal • tempfile • test.support • test.support.testresult • tk_rocket_units.py • tracemalloc • types • typing • unittest.case • unittest.loader • unittest.result • unittest.signals
`future` Package
imports: future.standard_library • future.utils
imported by: future.backports • future.backports.email.utils • future.backports.urllib.error • future.builtins • future.builtins.iterators • future.builtins.misc • future.moves • future.standard_library • future.types • future.utils • future.utils.surrogateescape • tk_rocket_units.py
`future.backports` Package
imports: __future__ • future • future.backports.datetime • future.backports.email • future.backports.misc • future.standard_library • sys
imported by: future.backports.datetime • future.backports.email • future.backports.email.charset • future.backports.email.header • future.backports.email.utils • future.backports.http • future.backports.misc • future.backports.urllib • future.backports.urllib.request • future.backports.urllib.robotparser
`future.backports.datetime` SourceModule
imports: __future__ • _datetime • _strptime • future.backports • future.builtins • future.utils • math • time
imported by: future.backports • future.backports.email.utils
`future.backports.email` Package
imports: __future__ • future.backports • future.backports.email.base64mime • future.backports.email.errors • future.backports.email.header • future.backports.email.message • future.backports.email.parser • future.backports.email.utils • future.utils • future.utils.surrogateescape
imported by: future.backports • future.backports.email._encoded_words • future.backports.email._parseaddr • future.backports.email._policybase • future.backports.email.base64mime • future.backports.email.charset • future.backports.email.encoders • future.backports.email.errors • future.backports.email.feedparser • future.backports.email.generator • future.backports.email.header • future.backports.email.iterators • future.backports.email.message • future.backports.email.parser • future.backports.email.quoprimime • future.backports.email.utils • future.backports.http.client • future.backports.urllib.request
`future.backports.email._encoded_words` SourceModule
imports: __future__ • base64 • binascii • functools • future.backports.email • future.backports.email.errors • future.builtins • re • string
imported by: future.backports.email.message
`future.backports.email._parseaddr` SourceModule
imports: __future__ • calendar • future.backports.email • future.builtins • time
imported by: future.backports.email.utils
`future.backports.email._policybase` SourceModule
imports: __future__ • abc • future.backports.email • future.backports.email.charset • future.backports.email.header • future.backports.email.utils • future.builtins • future.utils
imported by: future.backports.email.feedparser • future.backports.email.generator • future.backports.email.message • future.backports.email.parser
`future.backports.email.base64mime` SourceModule
imports: __future__ • base64 • binascii • future.backports.email • future.builtins
imported by: future.backports.email • future.backports.email.header
`future.backports.email.charset` SourceModule
imports: __future__ • functools • future.backports • future.backports.email • future.backports.email.encoders • future.backports.email.errors • future.builtins
imported by: future.backports.email._policybase • future.backports.email.generator • future.backports.email.header • future.backports.email.message • future.backports.email.utils
`future.backports.email.encoders` SourceModule
imports: __future__ • base64 • future.backports.email • future.builtins • quopri
imported by: future.backports.email.charset • future.backports.email.utils
`future.backports.email.errors` SourceModule
imports: __future__ • future.backports.email • future.builtins
imported by: future.backports.email • future.backports.email._encoded_words • future.backports.email.charset • future.backports.email.feedparser • future.backports.email.header • future.backports.email.message
`future.backports.email.feedparser` SourceModule
imports: __future__ • future.backports.email • future.backports.email._policybase • future.backports.email.errors • future.backports.email.message • future.builtins • future.utils • re
imported by: future.backports.email.parser
`future.backports.email.generator` SourceModule
imports: __future__ • future.backports.email • future.backports.email._policybase • future.backports.email.charset • future.backports.email.header • future.backports.email.utils • future.builtins • io • random • re • sys • time • warnings
imported by: future.backports.email.message
`future.backports.email.header` SourceModule
imports: __future__ • binascii • future.backports • future.backports.email • future.backports.email.base64mime • future.backports.email.charset • future.backports.email.errors • future.backports.email.quoprimime • future.builtins • re • sys
imported by: future.backports.email • future.backports.email._policybase • future.backports.email.generator
`future.backports.email.iterators` SourceModule
imports: __future__ • future.backports.email • io • sys
imported by: future.backports.email.message
`future.backports.email.message` SourceModule
imports: __future__ • base64 • binascii • future.backports.email • future.backports.email._encoded_words • future.backports.email._policybase • future.backports.email.charset • future.backports.email.errors • future.backports.email.generator • future.backports.email.iterators • future.backports.email.utils • future.builtins • future.utils • io • re • uu
imported by: future.backports.email • future.backports.email.feedparser • future.backports.email.parser • future.backports.http.client
`future.backports.email.parser` SourceModule
imports: __future__ • future.backports.email • future.backports.email._policybase • future.backports.email.feedparser • future.backports.email.message • io • warnings
imported by: future.backports.email • future.backports.http.client
`future.backports.email.quoprimime` SourceModule
imports: __future__ • future.backports.email • future.builtins • io • re • string
imported by: future.backports.email.header
`future.backports.email.utils` SourceModule
imports: __future__ • base64 • future • future.backports • future.backports.datetime • future.backports.email • future.backports.email._parseaddr • future.backports.email.charset • future.backports.email.encoders • future.backports.urllib.parse • future.builtins • future.utils • io • os • quopri • random • re • socket • time • warnings
imported by: future.backports.email • future.backports.email._policybase • future.backports.email.generator • future.backports.email.message • future.backports.urllib.request
`future.backports.http` Package
imports: future.backports • future.backports.http.client
imported by: future.backports.http.client • future.backports.http.cookiejar • future.backports.urllib.request
`future.backports.http.client` SourceModule
imports: __future__ • array • collections • future.backports.email • future.backports.email.message • future.backports.email.parser • future.backports.http • future.backports.misc • future.backports.urllib.parse • future.builtins • future.utils • io • os • socket • ssl • warnings
imported by: future.backports.http • future.backports.http.cookiejar • future.backports.urllib.request
`future.backports.http.cookiejar` SourceModule
imports: __future__ • calendar • copy • datetime • dummy_threading • future.backports.http • future.backports.http.client • future.backports.urllib.parse • future.builtins • future.utils • io • logging • re • threading • time • traceback • warnings
imported by: future.backports.urllib.request
`future.backports.misc` SourceModule
imports: __future__ • _dummy_thread • _thread • _weakref • collections • collections.Mapping • collections.MutableMapping • dummy_thread • functools • future.backports • future.utils • heapq • itertools • math • operator • reprlib • socket • subprocess • sys • thread
imported by: future.backports • future.backports.http.client • future.types.newrange
`future.backports.urllib` Package
imports: future.backports • future.backports.urllib.request • future.backports.urllib.response • future.backports.urllib.robotparser
imported by: future.backports.urllib.error • future.backports.urllib.parse • future.backports.urllib.request • future.backports.urllib.response • future.backports.urllib.robotparser • future.standard_library
`future.backports.urllib.error` SourceModule
imports: __future__ • future • future.backports.urllib • future.backports.urllib.response • future.standard_library
imported by: future.backports.urllib.request • future.standard_library
`future.backports.urllib.parse` SourceModule
imports: __future__ • collections • future.backports.urllib • future.builtins • future.utils • re • sys
imported by: future.backports.email.utils • future.backports.http.client • future.backports.http.cookiejar • future.backports.urllib.request • future.backports.urllib.robotparser • future.standard_library
`future.backports.urllib.request` SourceModule
imports: __future__ • _scproxy • array • base64 • bisect • collections • contextlib • fnmatch • ftplib • future.backports • future.backports.email • future.backports.email.utils • future.backports.http • future.backports.http.client • future.backports.http.cookiejar • future.backports.urllib • future.backports.urllib.error • future.backports.urllib.parse • future.backports.urllib.response • future.builtins • future.utils • getpass • hashlib • io • mimetypes • nturl2path • os • posixpath • re • socket • ssl • sys • tempfile • time • warnings • winreg
imported by: future.backports.urllib • future.backports.urllib.robotparser • future.standard_library
`future.backports.urllib.response` SourceModule
imports: __future__ • future.backports.urllib • future.builtins
imported by: future.backports.urllib • future.backports.urllib.error • future.backports.urllib.request • future.standard_library
`future.backports.urllib.robotparser` SourceModule
imports: __future__ • future.backports • future.backports.urllib • future.backports.urllib.parse • future.backports.urllib.request • future.builtins • time
imported by: future.backports.urllib • future.standard_library
`future.builtins` Package
imports: builtins • future • future.builtins.iterators • future.builtins.misc • future.types • future.types.newbytes • future.types.newdict • future.types.newint • future.types.newlist • future.types.newobject • future.types.newrange • future.types.newstr • future.utils
imported by: future.backports.datetime • future.backports.email._encoded_words • future.backports.email._parseaddr • future.backports.email._policybase • future.backports.email.base64mime • future.backports.email.charset • future.backports.email.encoders • future.backports.email.errors • future.backports.email.feedparser • future.backports.email.generator • future.backports.email.header • future.backports.email.message • future.backports.email.quoprimime • future.backports.email.utils • future.backports.http.client • future.backports.http.cookiejar • future.backports.urllib.parse • future.backports.urllib.request • future.backports.urllib.response • future.backports.urllib.robotparser • future.builtins.iterators • future.builtins.misc • future.builtins.newnext • future.builtins.newround • future.builtins.newsuper
`future.builtins.iterators` SourceModule
imports: __future__ • builtins • future • future.builtins • future.types • future.types.newrange • future.utils • itertools
imported by: future.builtins
`future.builtins.misc` SourceModule
imports: __builtin__ • builtins • future • future.builtins • future.builtins.newnext • future.builtins.newround • future.builtins.newsuper • future.types.newint • future.utils • future_builtins • io
imported by: future.builtins
`future.builtins.newnext` SourceModule
imports: future.builtins
imported by: future.builtins.misc
`future.builtins.newround` SourceModule
imports: decimal • future.builtins • future.utils • math
imported by: future.builtins.misc
`future.builtins.newsuper` SourceModule
imports: __future__ • future.builtins • future.utils • sys • types
imported by: future.builtins.misc
`future.moves` Package
imports: __future__ • future • future.standard_library • sys
imported by: future.moves.dbm • future.moves.test
`future.moves.dbm` Package
imports: __future__ • anydbm • dbm • dbm.ndbm • future.moves • future.moves.dbm • future.moves.dbm.dumb • future.moves.dbm.gnu • future.moves.dbm.ndbm • future.utils • whichdb
imported by: future.moves.dbm • future.moves.dbm.dumb • future.moves.dbm.gnu • future.moves.dbm.ndbm • future.standard_library
`future.moves.dbm.dumb` SourceModule
imports: __future__ • dbm.dumb • dumbdbm • future.moves.dbm • future.utils
imported by: future.moves.dbm • future.standard_library
`future.moves.dbm.gnu` SourceModule
imports: __future__ • dbm.gnu • future.moves.dbm • future.utils • gdbm
imported by: future.moves.dbm • future.standard_library
`future.moves.dbm.ndbm` SourceModule
imports: __future__ • dbm • dbm.ndbm • future.moves.dbm • future.utils
imported by: future.moves.dbm • future.standard_library
`future.moves.test` Package
imports: __future__ • future.moves • future.moves.test.support • future.utils
imported by: future.moves.test.support • future.standard_library
`future.moves.test.support` SourceModule
imports: __future__ • future.moves.test • future.standard_library • future.utils • test.support • test.test_support
imported by: future.moves.test • future.standard_library
`future.standard_library` Package
imports: __future__ • contextlib • copy • dbm • email • future • future.backports.urllib • future.backports.urllib.error • future.backports.urllib.parse • future.backports.urllib.request • future.backports.urllib.response • future.backports.urllib.robotparser • future.moves.dbm • future.moves.dbm.dumb • future.moves.dbm.gnu • future.moves.dbm.ndbm • future.moves.test • future.moves.test.support • future.utils • imp • importlib • logging • os • pickle • sys • test • types • urllib
imported by: future • future.backports • future.backports.urllib.error • future.moves • future.moves.test.support • tk_rocket_units.py
`future.types` Package
imports: __future__ • builtins • functools • future • future.types.newbytes • future.types.newdict • future.types.newint • future.types.newlist • future.types.newobject • future.types.newrange • future.types.newstr • future.utils • numbers
imported by: future.builtins • future.builtins.iterators • future.types.newbytes • future.types.newdict • future.types.newint • future.types.newlist • future.types.newobject • future.types.newrange • future.types.newstr • future.utils
`future.types.newbytes` SourceModule
imports: collections • collections.Iterable • copy • future.types • future.types.newobject • future.types.newstr • future.utils • future.utils.surrogateescape • numbers • string
imported by: future.builtins • future.types • future.types.newint • future.types.newstr • future.utils
`future.types.newdict` SourceModule
imports: future.types • future.types.newobject • future.utils • sys
imported by: future.builtins • future.types • future.utils
`future.types.newint` SourceModule
imports: __future__ • collections • future.types • future.types.newbytes • future.types.newobject • future.utils • struct
imported by: future.builtins • future.builtins.misc • future.types • future.utils
`future.types.newlist` SourceModule
imports: copy • future.types • future.types.newobject • future.utils • sys
imported by: future.builtins • future.types
`future.types.newobject` SourceModule
imports: future.types
imported by: future.builtins • future.types • future.types.newbytes • future.types.newdict • future.types.newint • future.types.newlist • future.types.newstr
`future.types.newrange` SourceModule
imports: __future__ • collections • collections.Iterator • collections.Sequence • future.backports.misc • future.types • itertools
imported by: future.builtins • future.builtins.iterators • future.types
`future.types.newstr` SourceModule
imports: collections • collections.Iterable • future.types • future.types.newbytes • future.types.newobject • future.utils • numbers
imported by: future.builtins • future.types • future.types.newbytes • future.utils
`future.utils` Package
imports: __builtin__ • builtins • copy • functools • future • future.types • future.types.newbytes • future.types.newdict • future.types.newint • future.types.newstr • inspect • numbers • re • sys • types
imported by: future • future.backports.datetime • future.backports.email • future.backports.email._policybase • future.backports.email.feedparser • future.backports.email.message • future.backports.email.utils • future.backports.http.client • future.backports.http.cookiejar • future.backports.misc • future.backports.urllib.parse • future.backports.urllib.request • future.builtins • future.builtins.iterators • future.builtins.misc • future.builtins.newround • future.builtins.newsuper • future.moves.dbm • future.moves.dbm.dumb • future.moves.dbm.gnu • future.moves.dbm.ndbm • future.moves.test • future.moves.test.support • future.standard_library • future.types • future.types.newbytes • future.types.newdict • future.types.newint • future.types.newlist • future.types.newstr • future.utils.surrogateescape
`future.utils.surrogateescape` SourceModule
imports: codecs • future • future.utils • sys
imported by: future.backports.email • future.types.newbytes
`future_builtins` MissingModule
imports: itertools
imported by: future.builtins.misc
`gc` (builtin module)
imports: time
imported by: _posixsubprocess • test.support • weakref
`gdbm` MissingModule
imported by: anydbm • future.moves.dbm.gnu
`genericpath` SourceModule
imports: os • stat
imported by: ntpath • posixpath
`getopt` SourceModule
imports: gettext • os • sys
imported by: base64 • distutils.fancy_getopt • mimetypes • pdb • pydoc • quopri • webbrowser
`getpass` SourceModule
imports: contextlib • io • msvcrt • os • pwd • sys • termios • warnings
imported by: future.backports.urllib.request • urllib.request
`gettext` SourceModule
imports: builtins • copy • errno • locale • os • re • struct • sys • warnings
imported by: argparse • getopt • optparse
`glob` SourceModule
imports: fnmatch • os • re
imported by: pdb • webbrowser
`grp` MissingModule
imported by: shutil • tarfile
`gzip` SourceModule
imports: _compression • builtins • errno • io • os • struct • sys • time • warnings • zlib
imported by: tarfile • test.support • xmlrpc.client
`hashlib` SourceModule
imports: _blake2 • _hashlib • _md5 • _sha1 • _sha256 • _sha3 • _sha512 • logging
imported by: future.backports.urllib.request • hmac • random • urllib.request
`heapq` SourceModule
imports: _heapq
imported by: collections • difflib • future.backports.misc • queue • sched • tk_rocket_units.py
`hmac` SourceModule
imports: _hashlib • _operator • hashlib • warnings
imported by: multiprocessing.connection • smtplib
`html` Package
imports: html.entities • re
imported by: html.entities • http.server
`html.entities` SourceModule
imports: html
imported by: html
`http` Package
imports: enum
imported by: http.client • http.cookiejar • http.server
`http.client` SourceModule
imports: collections.abc • email.message • email.parser • http • io • re • socket • ssl • urllib.parse • warnings
imported by: http.cookiejar • http.server • logging.handlers • urllib.request • xmlrpc.client
`http.cookiejar` SourceModule
imports: calendar • copy • datetime • http • http.client • io • logging • re • threading • time • traceback • urllib.parse • urllib.request • warnings
imported by: urllib.request
`http.server` SourceModule
imports: argparse • base64 • binascii • copy • datetime • email.utils • functools • html • http • http.client • io • mimetypes • os • posixpath • pwd • select • shutil • socket • socketserver • subprocess • sys • time • urllib.parse
imported by: pydoc
`imp` SourceModule
imports: _imp • importlib • importlib._bootstrap • importlib._bootstrap_external • importlib.machinery • importlib.util • os • sys • tokenize • types • warnings
imported by: future.standard_library • pywintypes
`importlib` Package
imports: _frozen_importlib • _frozen_importlib_external • _imp • importlib • importlib._bootstrap • importlib._bootstrap_external • importlib.abc • sys • types • warnings
imported by: future.standard_library • imp • importlib • importlib._bootstrap • importlib._bootstrap_external • importlib.abc • importlib.machinery • importlib.util • inspect • pkgutil • test.support • test.support.script_helper • test.test_support
`importlib._bootstrap` SourceModule
imports: _frozen_importlib_external • importlib
imported by: imp • importlib • importlib.abc • importlib.machinery • importlib.util • pydoc
`importlib._bootstrap_external` SourceModule
imports: importlib • tokenize
imported by: imp • importlib • importlib.abc • importlib.machinery • importlib.util • py_compile • pydoc
`importlib.abc` SourceModule
imports: _frozen_importlib • _frozen_importlib_external • abc • importlib • importlib._bootstrap • importlib._bootstrap_external • importlib.machinery • warnings
imported by: importlib • importlib.util
`importlib.machinery` SourceModule
imports: _imp • importlib • importlib._bootstrap • importlib._bootstrap_external
imported by: ctypes.util • imp • importlib.abc • inspect • pkgutil • py_compile • pydoc • runpy
`importlib.util` SourceModule
imports: _imp • contextlib • functools • importlib • importlib._bootstrap • importlib._bootstrap_external • importlib.abc • sys • types • warnings
imported by: distutils.util • imp • pkgutil • py_compile • pydoc • runpy • test.support • test.support.script_helper • zipfile
`inspect` SourceModule
imports: abc • argparse • ast • builtins • collections • collections.abc • dis • enum • functools • importlib • importlib.machinery • itertools • linecache • operator • os • re • sys • token • tokenize • types • warnings
imported by: ast • bdb • doctest • future.utils • pdb • pkgutil • pydoc
`io` SourceModule
imports: _io • abc
imported by: _compression • bz2 • dbm • dbm.dumb • dis • distutils.text_file • doctest • email.feedparser • email.generator • email.iterators • email.message • email.parser • encodings.quopri_codec • encodings.uu_codec • future.backports.email.generator • future.backports.email.iterators • future.backports.email.message • future.backports.email.parser • future.backports.email.quoprimime • future.backports.email.utils • future.backports.http.client • future.backports.http.cookiejar • future.backports.urllib.request • future.builtins.misc • getpass • gzip • http.client • http.cookiejar • http.server • lib2to3.patcomp • lib2to3.pgen2.driver • lib2to3.pytree • lib2to3.refactor • logging • lzma • multiprocessing.connection • multiprocessing.popen_forkserver • multiprocessing.popen_spawn_posix • multiprocessing.reduction • os • pickle • plistlib • pprint • pydoc • quopri • shlex • smtplib • socket • socketserver • subprocess • tarfile • tempfile • test.support • test.support.testresult • test.test_support • tk_rocket_units.py • tokenize • unittest.result • urllib.request • xml.etree.ElementTree • xml.sax • xml.sax.saxutils • xmlrpc.client • zipfile
`itertools` (builtin module)
imported by: _pydecimal • calendar • collections • ctypes.macholib.dyld • future.backports.misc • future.builtins.iterators • future.types.newrange • future_builtins • inspect • lib2to3.btm_matcher • lib2to3.refactor • multiprocessing.connection • multiprocessing.pool • multiprocessing.process • multiprocessing.util • pickle • plistlib • random • reprlib • threading • tokenize • traceback • weakref
`java` MissingModule
imported by: platform
`keyword` SourceModule
imports: re • sys
imported by: collections • tk_rocket_units.py
`linecache` SourceModule
imports: functools • os • sys • tokenize
imported by: bdb • doctest • inspect • pdb • tk_rocket_units.py • traceback • tracemalloc • warnings
`locale` SourceModule
imports: _bootlocale • _collections_abc • _locale • builtins • encodings • encodings.aliases • functools • os • re • sys • warnings
imported by: _bootlocale • _pydecimal • _strptime • calendar • gettext • test.support • tk_rocket_units.py • tkinter.filedialog • xml.etree.ElementTree
`logging` Package
imports: atexit • collections.abc • io • os • pickle • string • sys • threading • time • traceback • warnings • weakref
imported by: future.backports.http.cookiejar • future.standard_library • hashlib • http.cookiejar • lib2to3.btm_matcher • lib2to3.pgen2.driver • lib2to3.refactor • logging.handlers • multiprocessing.util • unittest.case
`logging.handlers` SourceModule
imports: base64 • copy • email.message • email.utils • http.client • logging • os • pickle • queue • re • smtplib • socket • stat • struct • threading • time • urllib.parse • win32evtlog • win32evtlogutil
imported by: test.support
`lzma` SourceModule
imports: _compression • _lzma • builtins • io • os
imported by: shutil • tarfile • test.support • zipfile
`marshal` (builtin module)
imported by: pkgutil
`math` (builtin module)
imported by: _pydecimal • datetime • future.backports.datetime • future.backports.misc • future.builtins.newround • random • selectors
`mimetypes` SourceModule
imports: getopt • os • posixpath • sys • urllib.parse • winreg
imported by: future.backports.urllib.request • http.server • urllib.request
`mmap` (builtin module)
imported by: multiprocessing.heap
`msvcrt` (builtin module)
imported by: getpass • multiprocessing.popen_spawn_win32 • multiprocessing.spawn • subprocess • test.support
`multiprocessing` Package
imports: multiprocessing • multiprocessing.AuthenticationError • multiprocessing.BufferTooShort • multiprocessing.TimeoutError • multiprocessing.context • multiprocessing.get_context • multiprocessing.get_start_method • multiprocessing.pool • multiprocessing.process • multiprocessing.reduction • multiprocessing.resource_sharer • multiprocessing.semaphore_tracker • multiprocessing.set_start_method • multiprocessing.spawn • multiprocessing.util • sys
imported by: lib2to3.refactor • multiprocessing • multiprocessing.connection • multiprocessing.context • multiprocessing.dummy • multiprocessing.forkserver • multiprocessing.heap • multiprocessing.managers • multiprocessing.pool • multiprocessing.popen_fork • multiprocessing.popen_forkserver • multiprocessing.popen_spawn_posix • multiprocessing.popen_spawn_win32 • multiprocessing.process • multiprocessing.queues • multiprocessing.reduction • multiprocessing.resource_sharer • multiprocessing.semaphore_tracker • multiprocessing.sharedctypes • multiprocessing.spawn • multiprocessing.synchronize • multiprocessing.util • pyi_rth_multiprocessing.py
`multiprocessing.AuthenticationError` MissingModule
imported by: multiprocessing • multiprocessing.connection
`multiprocessing.BufferTooShort` MissingModule
imported by: multiprocessing • multiprocessing.connection
`multiprocessing.TimeoutError` MissingModule
imported by: multiprocessing • multiprocessing.pool
`multiprocessing.connection` SourceModule
imports: _multiprocessing • _winapi • hmac • io • itertools • multiprocessing • multiprocessing.AuthenticationError • multiprocessing.BufferTooShort • multiprocessing.context • multiprocessing.resource_sharer • multiprocessing.util • os • selectors • socket • struct • sys • tempfile • time • xmlrpc.client
imported by: multiprocessing.context • multiprocessing.forkserver • multiprocessing.managers • multiprocessing.popen_fork • multiprocessing.popen_forkserver • multiprocessing.queues • multiprocessing.resource_sharer
`multiprocessing.context` SourceModule
imports: multiprocessing • multiprocessing.connection • multiprocessing.forkserver • multiprocessing.managers • multiprocessing.pool • multiprocessing.popen_fork • multiprocessing.popen_forkserver • multiprocessing.popen_spawn_posix • multiprocessing.popen_spawn_win32 • multiprocessing.process • multiprocessing.queues • multiprocessing.reduction • multiprocessing.sharedctypes • multiprocessing.spawn • multiprocessing.synchronize • multiprocessing.util • os • sys • threading
imported by: multiprocessing • multiprocessing.connection • multiprocessing.forkserver • multiprocessing.heap • multiprocessing.managers • multiprocessing.popen_forkserver • multiprocessing.popen_spawn_posix • multiprocessing.popen_spawn_win32 • multiprocessing.process • multiprocessing.queues • multiprocessing.reduction • multiprocessing.resource_sharer • multiprocessing.sharedctypes • multiprocessing.spawn • multiprocessing.synchronize
`multiprocessing.dummy` Package
imports: array • multiprocessing • multiprocessing.dummy.connection • multiprocessing.pool • queue • sys • threading • weakref
imported by: multiprocessing.dummy.connection • multiprocessing.pool
`multiprocessing.dummy.connection` SourceModule
imports: multiprocessing.dummy • queue
imported by: multiprocessing.dummy
`multiprocessing.forkserver` SourceModule
imports: errno • multiprocessing • multiprocessing.connection • multiprocessing.context • multiprocessing.process • multiprocessing.semaphore_tracker • multiprocessing.spawn • multiprocessing.util • os • selectors • signal • socket • struct • sys • threading • warnings
imported by: multiprocessing.context • multiprocessing.popen_forkserver
`multiprocessing.get_context` MissingModule
imported by: multiprocessing • multiprocessing.managers • multiprocessing.pool • multiprocessing.sharedctypes
`multiprocessing.get_start_method` MissingModule
imported by: multiprocessing • multiprocessing.spawn
`multiprocessing.heap` SourceModule
imports: _winapi • bisect • mmap • multiprocessing • multiprocessing.context • multiprocessing.util • os • sys • tempfile • threading
imported by: multiprocessing.sharedctypes • multiprocessing.synchronize
`multiprocessing.managers` SourceModule
imports: array • multiprocessing • multiprocessing.connection • multiprocessing.context • multiprocessing.get_context • multiprocessing.pool • multiprocessing.process • multiprocessing.util • queue • sys • threading • time • traceback
imported by: multiprocessing.context
`multiprocessing.pool` SourceModule
imports: collections • itertools • multiprocessing • multiprocessing.TimeoutError • multiprocessing.dummy • multiprocessing.get_context • multiprocessing.util • os • queue • threading • time • traceback
imported by: multiprocessing • multiprocessing.context • multiprocessing.dummy • multiprocessing.managers
`multiprocessing.popen_fork` SourceModule
imports: multiprocessing • multiprocessing.connection • multiprocessing.util • os • signal • sys
imported by: multiprocessing.context • multiprocessing.popen_forkserver • multiprocessing.popen_spawn_posix • pyi_rth_multiprocessing.py
`multiprocessing.popen_forkserver` SourceModule
imports: io • multiprocessing • multiprocessing.connection • multiprocessing.context • multiprocessing.forkserver • multiprocessing.popen_fork • multiprocessing.spawn • multiprocessing.util • os
imported by: multiprocessing.context
`multiprocessing.popen_spawn_posix` SourceModule
imports: io • multiprocessing • multiprocessing.context • multiprocessing.popen_fork • multiprocessing.semaphore_tracker • multiprocessing.spawn • multiprocessing.util • os
imported by: multiprocessing.context • pyi_rth_multiprocessing.py
`multiprocessing.popen_spawn_win32` SourceModule
imports: _winapi • msvcrt • multiprocessing • multiprocessing.context • multiprocessing.spawn • multiprocessing.util • os • signal • sys
imported by: multiprocessing.context • pyi_rth_multiprocessing.py
`multiprocessing.process` SourceModule
imports: _weakrefset • itertools • multiprocessing • multiprocessing.context • multiprocessing.util • os • signal • sys • threading • traceback
imported by: multiprocessing • multiprocessing.context • multiprocessing.forkserver • multiprocessing.managers • multiprocessing.resource_sharer • multiprocessing.spawn • multiprocessing.synchronize • multiprocessing.util • test.support
`multiprocessing.queues` SourceModule
imports: _multiprocessing • collections • errno • multiprocessing • multiprocessing.connection • multiprocessing.context • multiprocessing.synchronize • multiprocessing.util • os • queue • sys • threading • time • traceback • weakref
imported by: multiprocessing.context
`multiprocessing.reduction` SourceModule
imports: _winapi • abc • array • copyreg • functools • io • multiprocessing • multiprocessing.context • multiprocessing.resource_sharer • os • pickle • socket • sys
imported by: multiprocessing • multiprocessing.context
`multiprocessing.resource_sharer` SourceModule
imports: multiprocessing • multiprocessing.connection • multiprocessing.context • multiprocessing.process • multiprocessing.util • os • signal • socket • sys • threading
imported by: multiprocessing • multiprocessing.connection • multiprocessing.reduction
`multiprocessing.semaphore_tracker` SourceModule
imports: _multiprocessing • multiprocessing • multiprocessing.spawn • multiprocessing.util • os • signal • sys • threading • warnings
imported by: multiprocessing • multiprocessing.forkserver • multiprocessing.popen_spawn_posix • multiprocessing.spawn • multiprocessing.synchronize
`multiprocessing.set_start_method` MissingModule
imported by: multiprocessing • multiprocessing.spawn
`multiprocessing.sharedctypes` SourceModule
imports: ctypes • multiprocessing • multiprocessing.context • multiprocessing.get_context • multiprocessing.heap • weakref
imported by: multiprocessing.context
`multiprocessing.spawn` SourceModule
imports: msvcrt • multiprocessing • multiprocessing.context • multiprocessing.get_start_method • multiprocessing.process • multiprocessing.semaphore_tracker • multiprocessing.set_start_method • multiprocessing.util • os • runpy • sys • types
imported by: multiprocessing • multiprocessing.context • multiprocessing.forkserver • multiprocessing.popen_forkserver • multiprocessing.popen_spawn_posix • multiprocessing.popen_spawn_win32 • multiprocessing.semaphore_tracker • pyi_rth_multiprocessing.py
`multiprocessing.synchronize` SourceModule
imports: _multiprocessing • multiprocessing • multiprocessing.context • multiprocessing.heap • multiprocessing.process • multiprocessing.semaphore_tracker • multiprocessing.util • struct • sys • tempfile • threading • time
imported by: multiprocessing.context • multiprocessing.queues
`multiprocessing.util` SourceModule
imports: _posixsubprocess • atexit • itertools • logging • multiprocessing • multiprocessing.process • os • shutil • subprocess • sys • tempfile • threading • traceback • weakref
imported by: multiprocessing • multiprocessing.connection • multiprocessing.context • multiprocessing.forkserver • multiprocessing.heap • multiprocessing.managers • multiprocessing.pool • multiprocessing.popen_fork • multiprocessing.popen_forkserver • multiprocessing.popen_spawn_posix • multiprocessing.popen_spawn_win32 • multiprocessing.process • multiprocessing.queues • multiprocessing.resource_sharer • multiprocessing.semaphore_tracker • multiprocessing.spawn • multiprocessing.synchronize
`netrc` SourceModule
imports: os • pwd • shlex • stat
imported by: ftplib • nntplib
`nntplib` SourceModule
imports: argparse • collections • datetime • email.header • netrc • re • socket • ssl • warnings
imported by: test.support
`nt` (builtin module)
imported by: ntpath • os • shutil
`ntpath` SourceModule
imports: genericpath • nt • os • stat • string • sys
imported by: ntpath • os
`ntpath` AliasNode
imports: ntpath • os
imported by: distutils.file_util • os • pkgutil • py_compile • sysconfig • test.support.script_helper • tracemalloc • unittest • unittest.util
`nturl2path` SourceModule
imports: string • urllib.parse
imported by: future.backports.urllib.request • urllib.request
`numbers` SourceModule
imports: abc
imported by: _pydecimal • future.types • future.types.newbytes • future.types.newstr • future.utils
`opcode` SourceModule
imports: _opcode
imported by: dis
`operator` SourceModule
imports: _operator • builtins • functools
imported by: collections • email._header_value_parser • future.backports.misc • inspect • lib2to3.refactor • tk_rocket_units.py • typing
`optparse` SourceModule
imports: gettext • os • sys • textwrap
imported by: uu
`org` MissingModule
imported by: copy
`os` SourceModule
imports: _collections_abc • abc • io • nt • ntpath • ntpath • posix • posixpath • stat • subprocess • sys • warnings
imported by: _osx_support • argparse • bdb • bz2 • ctypes • ctypes._aix • ctypes.macholib.dyld • ctypes.util • dbm • dbm.dumb • distutils.ccompiler • distutils.debug • distutils.dep_util • distutils.dir_util • distutils.file_util • distutils.filelist • distutils.spawn • distutils.sysconfig • distutils.util • doctest • email.utils • fnmatch • future.backports.email.utils • future.backports.http.client • future.backports.urllib.request • future.standard_library • genericpath • getopt • getpass • gettext • glob • gzip • http.server • imp • inspect • lib2to3.pgen2.driver • lib2to3.pygram • lib2to3.refactor • linecache • locale • logging • logging.handlers • lzma • mimetypes • multiprocessing.connection • multiprocessing.context • multiprocessing.forkserver • multiprocessing.heap • multiprocessing.pool • multiprocessing.popen_fork • multiprocessing.popen_forkserver • multiprocessing.popen_spawn_posix • multiprocessing.popen_spawn_win32 • multiprocessing.process • multiprocessing.queues • multiprocessing.reduction • multiprocessing.resource_sharer • multiprocessing.semaphore_tracker • multiprocessing.spawn • multiprocessing.util • netrc • ntpath • ntpath • optparse • pdb • pkgutil • platform • plistlib • posixpath • py_compile • pydoc • pyi_rth__tkinter.py • pyi_rth_multiprocessing.py • pywintypes • random • rocket_units • rocketunits.rocket_units • shlex • shutil • socket • socketserver • ssl • subprocess • sysconfig • tarfile • tempfile • test.support • test.support.script_helper • test.test_support • threading • tkinter • tkinter.filedialog • tkinter.ttk • unittest.loader • unittest.main • urllib.request • uu • webbrowser • xml.sax • xml.sax.saxutils • zipfile
`pdb` SourceModule
imports: bdb • cmd • code • dis • getopt • glob • inspect • linecache • os • pdb • pprint • pydoc • re • readline • runpy • shlex • signal • sys • traceback
imported by: doctest • pdb
`pickle` SourceModule
imports: 'org.python' • _compat_pickle • _pickle • codecs • copyreg • doctest • functools • io • itertools • pprint • re • struct • sys • types
imported by: future.standard_library • lib2to3.pgen2.grammar • logging • logging.handlers • multiprocessing.reduction • tracemalloc
`pkgutil` SourceModule
imports: collections • functools • importlib • importlib.machinery • importlib.util • inspect • marshal • ntpath • os • sys • types • warnings • zipimport
imported by: lib2to3.pgen2.driver • pydoc • runpy
`platform` SourceModule
imports: 'java.lang' • _winreg • collections • java • os • plistlib • re • socket • struct • subprocess • sys • vms_lib • warnings • winreg
imported by: pydoc • test.support
`plistlib` SourceModule
imports: binascii • codecs • contextlib • datetime • enum • io • itertools • os • re • struct • warnings • xml.parsers.expat
imported by: platform
`posix` MissingModule
imports: resource
imported by: os
`posixpath` SourceModule
imports: genericpath • os • pwd • re • stat • sys
imported by: fnmatch • future.backports.urllib.request • http.server • mimetypes • os • urllib.request
`pprint` SourceModule
imports: collections • io • re • sys • time • types
imported by: lib2to3.pgen2.grammar • pdb • pickle • sysconfig • unittest.case
`pwd` MissingModule
imported by: distutils.util • getpass • http.server • netrc • posixpath • shutil • tarfile • webbrowser
`py_compile` SourceModule
imports: enum • importlib._bootstrap_external • importlib.machinery • importlib.util • ntpath • os • sys • traceback
imported by: distutils.util • test.support.script_helper • zipfile
`pydoc` SourceModule
imports: builtins • collections • email.message • getopt • http.server • importlib._bootstrap • importlib._bootstrap_external • importlib.machinery • importlib.util • inspect • io • os • pkgutil • platform • pydoc_data.topics • re • reprlib • select • subprocess • sys • tempfile • textwrap • threading • time • tokenize • traceback • tty • urllib.parse • warnings • webbrowser
imported by: pdb
`pydoc_data` Package
imported by: pydoc_data.topics
`pydoc_data.topics` SourceModule
imports: pydoc_data
imported by: pydoc
`pyexpat` `d:\python37_64\DLLs\pyexpat.pyd`
imported by: _elementtree • xml.etree.ElementTree • xml.parsers.expat
`pywintypes` SourceModule
imports: _win32sysloader • distutils.sysconfig • imp • os • sys
imported by: pyi_rth_win32api.py
`queue` SourceModule
imports: _queue • collections • heapq • threading • time
imported by: logging.handlers • multiprocessing.dummy • multiprocessing.dummy.connection • multiprocessing.managers • multiprocessing.pool • multiprocessing.queues
`quopri` SourceModule
imports: binascii • getopt • io • sys
imported by: email.encoders • email.message • encodings.quopri_codec • future.backports.email.encoders • future.backports.email.utils
`random` SourceModule
imports: _collections_abc • _random • bisect • hashlib • itertools • math • os • time • types • warnings
imported by: email.generator • email.utils • future.backports.email.generator • future.backports.email.utils • tempfile
`re` SourceModule
imports: _locale • copyreg • enum • functools • sre_compile • sre_constants • sre_parse
imported by: _osx_support • _pydecimal • _sre • _strptime • argparse • base64 • ctypes._aix • ctypes.macholib.dylib • ctypes.macholib.framework • ctypes.util • difflib • distutils.ccompiler • distutils.fancy_getopt • distutils.filelist • distutils.sysconfig • distutils.util • doctest • email._encoded_words • email._header_value_parser • email.feedparser • email.generator • email.header • email.message • email.policy • email.quoprimime • email.utils • encodings.idna • fnmatch • ftplib • future.backports.email._encoded_words • future.backports.email.feedparser • future.backports.email.generator • future.backports.email.header • future.backports.email.message • future.backports.email.quoprimime • future.backports.email.utils • future.backports.http.cookiejar • future.backports.urllib.parse • future.backports.urllib.request • future.utils • gettext • glob • html • http.client • http.cookiejar • inspect • keyword • lib2to3.pgen2.literals • lib2to3.pgen2.tokenize • locale • logging.handlers • nntplib • pdb • pickle • platform • plistlib • posixpath • pprint • pydoc • pyi_rth_multiprocessing.py • shlex • smtplib • string • sysconfig • tarfile • test.support • textwrap • tk_rocket_units.py • tkinter • token • tokenize • typing • unittest.case • unittest.loader • urllib.parse • urllib.request • warnings • xml.etree.ElementPath • xml.etree.ElementTree
`readline` MissingModule
imported by: cmd • code • pdb
`reprlib` SourceModule
imports: _thread • builtins • itertools
imported by: bdb • collections • functools • future.backports.misc • pydoc • tk_rocket_units.py
`resource` MissingModule
imported by: posix • test.support
`rocket_units` SourceModule
imports: os
imported by: tk_rocket_units.py
`rocketunits` Package
imported by: rocketunits.rocket_units
`rocketunits.rocket_units` SourceModule
imports: os • rocketunits
imported by: tk_rocket_units.py
`runpy` SourceModule
imports: importlib.machinery • importlib.util • pkgutil • sys • types • warnings
imported by: multiprocessing.spawn • pdb
`sched` SourceModule
imports: collections • heapq • threading • time
imported by: test.test_support
`select` `d:\python37_64\DLLs\select.pyd`
imported by: http.server • pydoc • selectors • subprocess
`selectors` SourceModule
imports: abc • collections • collections.abc • math • select • sys
imported by: multiprocessing.connection • multiprocessing.forkserver • socket • socketserver • subprocess
`shlex` SourceModule
imports: collections • io • os • re • sys
imported by: netrc • pdb • webbrowser
`shutil` SourceModule
imports: bz2 • collections • errno • fnmatch • grp • lzma • nt • os • pwd • stat • sys • tarfile • zipfile • zlib
imported by: ctypes.util • http.server • multiprocessing.util • tarfile • tempfile • test.support • test.test_support • webbrowser • zipfile
`signal` SourceModule
imports: _signal • enum • functools
imported by: multiprocessing.forkserver • multiprocessing.popen_fork • multiprocessing.popen_spawn_win32 • multiprocessing.process • multiprocessing.resource_sharer • multiprocessing.semaphore_tracker • pdb • subprocess • test.support • unittest.signals
`smtplib` SourceModule
imports: base64 • copy • datetime • email.base64mime • email.generator • email.message • email.utils • hmac • io • re • socket • ssl • sys • warnings
imported by: logging.handlers
`socket` SourceModule
imports: _socket • enum • errno • io • os • selectors • sys
imported by: _ssl • email.utils • ftplib • future.backports.email.utils • future.backports.http.client • future.backports.misc • future.backports.urllib.request • http.client • http.server • logging.handlers • multiprocessing.connection • multiprocessing.forkserver • multiprocessing.reduction • multiprocessing.resource_sharer • nntplib • platform • smtplib • socketserver • ssl • test.support • test.test_support • urllib.request • webbrowser
`socketserver` SourceModule
imports: io • os • selectors • socket • sys • threading • time • traceback
imported by: http.server
`sre_compile` SourceModule
imports: _sre • sre_constants • sre_parse • sys
imported by: re • tk_rocket_units.py
`sre_constants` SourceModule
imports: _sre
imported by: re • sre_compile • sre_parse • tk_rocket_units.py
`sre_parse` SourceModule
imports: sre_constants • warnings
imported by: re • sre_compile • tk_rocket_units.py
`ssl` SourceModule
imports: _ssl • base64 • calendar • collections • enum • errno • os • socket • sys • time • warnings
imported by: ftplib • future.backports.http.client • future.backports.urllib.request • http.client • nntplib • smtplib • urllib.request
`stat` SourceModule
imports: _stat
imported by: distutils.dep_util • distutils.file_util • genericpath • logging.handlers • netrc • ntpath • os • posixpath • shutil • tarfile • test.support • test.test_support • zipfile
`string` SourceModule
imports: _string • collections • re
imported by: cmd • distutils.fancy_getopt • distutils.util • email._encoded_words • email._header_value_parser • email.quoprimime • future.backports.email._encoded_words • future.backports.email.quoprimime • future.types.newbytes • lib2to3.pgen2.tokenize • logging • ntpath • nturl2path • urllib.request
`stringprep` SourceModule
imports: unicodedata
imported by: encodings.idna
`struct` SourceModule
imports: _struct
imported by: base64 • ctypes • ctypes.util • dbm • future.types.newint • gettext • gzip • logging.handlers • multiprocessing.connection • multiprocessing.forkserver • multiprocessing.synchronize • pickle • platform • plistlib • tarfile • test.support • zipfile
`subprocess` SourceModule
imports: _posixsubprocess • _winapi • builtins • errno • io • msvcrt • os • select • selectors • signal • sys • threading • time • warnings
imported by: ctypes._aix • ctypes.util • distutils.util • future.backports.misc • http.server • multiprocessing.util • os • platform • pydoc • pyi_rth_multiprocessing.py • test.support • test.support.script_helper • test.test_support • webbrowser
`sys` (builtin module)
imported by: _bootlocale • _collections_abc • _osx_support • _pydecimal • argparse • base64 • bdb • calendar • cmd • code • codecs • collections • contextlib • ctypes • ctypes._aix • ctypes._endian • ctypes.util • datetime • dbm • dis • distutils • distutils.ccompiler • distutils.fancy_getopt • distutils.log • distutils.spawn • distutils.sysconfig • distutils.text_file • distutils.util • doctest • dummy_threading • email._header_value_parser • email.generator • email.iterators • email.policy • encodings • encodings.rot_13 • encodings.utf_16 • encodings.utf_32 • enum • ftplib • future.backports • future.backports.email.generator • future.backports.email.header • future.backports.email.iterators • future.backports.misc • future.backports.urllib.parse • future.backports.urllib.request • future.builtins.newsuper • future.moves • future.standard_library • future.types.newdict • future.types.newlist • future.utils • future.utils.surrogateescape • getopt • getpass • gettext • gzip • http.server • imp • importlib • importlib.util • inspect • keyword • lib2to3.pgen2.driver • lib2to3.pgen2.tokenize • lib2to3.pytree • lib2to3.refactor • linecache • locale • logging • mimetypes • multiprocessing • multiprocessing.connection • multiprocessing.context • multiprocessing.dummy • multiprocessing.forkserver • multiprocessing.heap • multiprocessing.managers • multiprocessing.popen_fork • multiprocessing.popen_spawn_win32 • multiprocessing.process • multiprocessing.queues • multiprocessing.reduction • multiprocessing.resource_sharer • multiprocessing.semaphore_tracker • multiprocessing.spawn • multiprocessing.synchronize • multiprocessing.util • ntpath • optparse • os • pdb • pickle • pkgutil • platform • posixpath • pprint • py_compile • pydoc • pyi_rth__tkinter.py • pyi_rth_multiprocessing.py • pywintypes • quopri • runpy • selectors • shlex • shutil • smtplib • socket • socketserver • sre_compile • ssl • subprocess • sysconfig • tarfile • test.support • test.support.script_helper • test.support.testresult • test.test_support • threading • tkinter • tkinter.filedialog • token • tokenize • traceback • types • typing • unittest.case • unittest.loader • unittest.main • unittest.result • unittest.runner • unittest.suite • urllib.parse • urllib.request • uu • warnings • weakref • webbrowser • xml.etree.ElementTree • xml.parsers.expat • xml.sax • xml.sax._exceptions • xml.sax.expatreader • xml.sax.saxutils • xmlrpc.client • zipfile
`sysconfig` SourceModule
imports: _osx_support • ntpath • os • pprint • re • sys • types • warnings
imported by: test.support
`tarfile` SourceModule
imports: argparse • builtins • bz2 • copy • grp • gzip • io • lzma • os • pwd • re • shutil • stat • struct • sys • time • warnings • zlib
imported by: shutil
`tempfile` SourceModule
imports: _thread • errno • functools • io • os • random • shutil • warnings • weakref
imported by: _osx_support • ctypes.util • distutils.ccompiler • distutils.util • future.backports.urllib.request • multiprocessing.connection • multiprocessing.heap • multiprocessing.synchronize • multiprocessing.util • pydoc • test.support • test.test_support • urllib.request • urllib.response • webbrowser
`termios` MissingModule
imported by: getpass • tty
`test` Package
imported by: future.standard_library • test.support • test.test_support
`test.support` Package
imports: _testcapi • _thread • bz2 • collections.abc • contextlib • ctypes • ctypes.util • ctypes.wintypes • datetime • distutils • distutils.ccompiler • distutils.spawn • distutils.sysconfig • doctest • errno • faulthandler • fnmatch • functools • gc • gzip • importlib • importlib.util • io • locale • logging.handlers • lzma • msvcrt • multiprocessing.process • nntplib • os • platform • re • resource • shutil • signal • socket • stat • struct • subprocess • sys • sysconfig • tempfile • test • test.support.script_helper • test.support.testresult • threading • time • tkinter • tracemalloc • types • unicodedata • unittest • urllib.error • urllib.parse • urllib.request • warnings • zlib
imported by: future.moves.test.support • test.support.script_helper • test.support.testresult • test.test_support
`test.support.script_helper` SourceModule
imports: collections • importlib • importlib.util • ntpath • os • py_compile • subprocess • sys • test.support • zipfile
imported by: test.support • test.test_support
`test.support.testresult` SourceModule
imports: datetime • functools • io • sys • test.support • time • traceback • unittest • xml.etree.ElementTree
imported by: test.support
`test.test_support` SourceModule
imports: contextlib • errno • importlib • io • os • sched • shutil • socket • stat • subprocess • sys • tempfile • test • test.support • test.support.script_helper • textwrap • time • unittest
imported by: future.moves.test.support
`textwrap` SourceModule
imports: re
imported by: argparse • optparse • pydoc • test.test_support
`thread` MissingModule
imported by: future.backports.misc
`threading` SourceModule
imports: _collections • _thread • _threading_local • _weakrefset • collections • itertools • os • sys • time • traceback • warnings
imported by: _threading_local • bz2 • dummy_threading • future.backports.http.cookiejar • http.cookiejar • logging • logging.handlers • multiprocessing.context • multiprocessing.dummy • multiprocessing.forkserver • multiprocessing.heap • multiprocessing.managers • multiprocessing.pool • multiprocessing.process • multiprocessing.queues • multiprocessing.resource_sharer • multiprocessing.semaphore_tracker • multiprocessing.synchronize • multiprocessing.util • pydoc • queue • sched • socketserver • subprocess • test.support • webbrowser • zipfile
`time` (builtin module)
imports: _strptime
imported by: _datetime • _dummy_thread • _strptime • datetime • email._parseaddr • email.generator • email.utils • future.backports.datetime • future.backports.email._parseaddr • future.backports.email.generator • future.backports.email.utils • future.backports.http.cookiejar • future.backports.urllib.request • future.backports.urllib.robotparser • gc • gzip • http.cookiejar • http.server • logging • logging.handlers • multiprocessing.connection • multiprocessing.managers • multiprocessing.pool • multiprocessing.queues • multiprocessing.synchronize • pprint • pydoc • queue • random • sched • socketserver • ssl • subprocess • tarfile • test.support • test.support.testresult • test.test_support • threading • unittest.runner • urllib.request • xmlrpc.client • zipfile
`tkinter` Package
imports: _tkinter • enum • os • re • sys • tkinter.commondialog • tkinter.constants • traceback
imported by: test.support • tk_rocket_units.py • tkinter.commondialog • tkinter.constants • tkinter.dialog • tkinter.filedialog • tkinter.ttk
`tkinter.commondialog` SourceModule
imports: tkinter
imported by: tkinter • tkinter.filedialog
`tkinter.constants` SourceModule
imports: tkinter
imported by: tkinter
`tkinter.dialog` SourceModule
imports: tkinter
imported by: tkinter.filedialog
`tkinter.filedialog` SourceModule
imports: fnmatch • locale • os • sys • tkinter • tkinter.commondialog • tkinter.dialog
imported by: tk_rocket_units.py
`tkinter.ttk` SourceModule
imports: os • tkinter • warnings
imported by: tk_rocket_units.py
`token` SourceModule
imports: re • sys
imported by: inspect • tokenize
`tokenize` SourceModule
imports: argparse • builtins • codecs • collections • io • itertools • re • sys • token
imported by: imp • importlib._bootstrap_external • inspect • linecache • pydoc
`traceback` SourceModule
imports: collections • itertools • linecache • sys
imported by: _dummy_thread • code • doctest • future.backports.http.cookiejar • http.cookiejar • logging • multiprocessing.managers • multiprocessing.pool • multiprocessing.process • multiprocessing.queues • multiprocessing.util • pdb • py_compile • pydoc • socketserver • test.support.testresult • threading • tk_rocket_units.py • tkinter • unittest.case • unittest.loader • unittest.result • warnings
`tracemalloc` SourceModule
imports: _tracemalloc • collections.abc • fnmatch • functools • linecache • ntpath • pickle
imported by: test.support • warnings
`tty` SourceModule
imports: termios
imported by: pydoc
`types` SourceModule
imports: _collections_abc • functools • sys
imported by: copy • dis • email.headerregistry • enum • functools • future.builtins.newsuper • future.standard_library • future.utils • imp • importlib • importlib.util • inspect • multiprocessing.spawn • pickle • pkgutil • pprint • random • runpy • sysconfig • test.support • tk_rocket_units.py • typing • unittest.loader
`typing` SourceModule
imports: abc • collections • collections.abc • contextlib • functools • operator • re • sys • types
imported by: functools
`unicodedata` `d:\python37_64\DLLs\unicodedata.pyd`
imported by: encodings.idna • stringprep • test.support • urllib.parse
`unittest` Package
imports: ntpath • unittest • unittest.case • unittest.loader • unittest.main • unittest.result • unittest.runner • unittest.signals • unittest.suite • unittest.util
imported by: doctest • test.support • test.support.testresult • test.test_support • unittest • unittest.case • unittest.loader • unittest.main • unittest.result • unittest.runner • unittest.signals • unittest.suite • unittest.util
`unittest.case` SourceModule
imports: collections • contextlib • difflib • functools • logging • pprint • re • sys • traceback • unittest • unittest.result • unittest.util • warnings
imported by: unittest • unittest.loader • unittest.suite
`unittest.loader` SourceModule
imports: fnmatch • functools • os • re • sys • traceback • types • unittest • unittest.case • unittest.suite • unittest.util • warnings
imported by: unittest • unittest.main
`unittest.main` SourceModule
imports: argparse • os • sys • unittest • unittest.loader • unittest.runner • unittest.signals
imported by: unittest
`unittest.result` SourceModule
imports: functools • io • sys • traceback • unittest • unittest.util
imported by: unittest • unittest.case • unittest.runner
`unittest.runner` SourceModule
imports: sys • time • unittest • unittest.result • unittest.signals • warnings
imported by: unittest • unittest.main
`unittest.signals` SourceModule
imports: functools • signal • unittest • weakref
imported by: unittest • unittest.main • unittest.runner
`unittest.suite` SourceModule
imports: sys • unittest • unittest.case • unittest.util
imported by: unittest • unittest.loader
`unittest.util` SourceModule
imports: collections • ntpath • unittest
imported by: unittest • unittest.case • unittest.loader • unittest.result • unittest.suite
`urllib` Package
imported by: email._header_value_parser • future.standard_library • urllib.error • urllib.parse • urllib.request • urllib.response
`urllib.error` SourceModule
imports: urllib • urllib.response
imported by: test.support • urllib.request
`urllib.parse` SourceModule
imports: collections • re • sys • unicodedata • urllib
imported by: email.utils • http.client • http.cookiejar • http.server • logging.handlers • mimetypes • nturl2path • pydoc • test.support • urllib.request • xml.sax.saxutils • xmlrpc.client
`urllib.request` SourceModule
imports: _scproxy • base64 • bisect • contextlib • email • email.utils • fnmatch • ftplib • getpass • hashlib • http.client • http.cookiejar • io • mimetypes • nturl2path • os • posixpath • re • socket • ssl • string • sys • tempfile • time • urllib • urllib.error • urllib.parse • urllib.response • warnings • winreg
imported by: http.cookiejar • test.support • xml.sax.saxutils
`urllib.response` SourceModule
imports: tempfile • urllib
imported by: urllib.error • urllib.request
`uu` SourceModule
imports: binascii • optparse • os • sys
imported by: email.message • future.backports.email.message
`vms_lib` MissingModule
imported by: platform
`warnings` SourceModule
imports: _warnings • linecache • re • sys • traceback • tracemalloc
imported by: argparse • base64 • bz2 • collections • dbm.dumb • distutils.sysconfig • enum • ftplib • future.backports.email.generator • future.backports.email.parser • future.backports.email.utils • future.backports.http.client • future.backports.http.cookiejar • future.backports.urllib.request • getpass • gettext • gzip • hmac • http.client • http.cookiejar • imp • importlib • importlib.abc • importlib.util • inspect • locale • logging • multiprocessing.forkserver • multiprocessing.semaphore_tracker • nntplib • os • pkgutil • platform • plistlib • pydoc • random • runpy • smtplib • sre_parse • ssl • subprocess • sysconfig • tarfile • tempfile • test.support • threading • tk_rocket_units.py • tkinter.ttk • unittest.case • unittest.loader • unittest.runner • urllib.request • xml.etree.ElementTree • zipfile
`weakref` SourceModule
imports: _collections_abc • _weakref • _weakrefset • atexit • copy • gc • itertools • sys
imported by: _threading_local • copy • functools • logging • multiprocessing.dummy • multiprocessing.queues • multiprocessing.sharedctypes • multiprocessing.util • tempfile • tk_rocket_units.py • unittest.signals • xml.sax.expatreader
`webbrowser` SourceModule
imports: copy • getopt • glob • os • pwd • shlex • shutil • socket • subprocess • sys • tempfile • threading
imported by: pydoc
`whichdb` MissingModule
imported by: anydbm • future.moves.dbm
`win32api` `d:\python37_64\lib\site-packages\win32\win32api.pyd`
imported by: win32evtlogutil
`win32con` SourceModule
imported by: win32evtlogutil
`win32evtlog` `d:\python37_64\lib\site-packages\win32\win32evtlog.pyd`
imported by: logging.handlers • win32evtlogutil
`win32evtlogutil` SourceModule
imports: win32api • win32con • win32evtlog • winerror
imported by: logging.handlers
`winerror` SourceModule
imported by: win32evtlogutil
`winreg` (builtin module)
imported by: future.backports.urllib.request • mimetypes • platform • urllib.request
`xml` Package
imports: xml.sax.expatreader • xml.sax.xmlreader
imported by: xml.etree • xml.parsers • xml.sax
`xml.etree` Package
imports: xml • xml.etree • xml.etree.ElementPath • xml.etree.ElementTree
imported by: xml.etree • xml.etree.ElementInclude • xml.etree.ElementPath • xml.etree.ElementTree • xml.etree.cElementTree
`xml.etree.ElementInclude` SourceModule
imports: copy • xml.etree • xml.etree.ElementTree
imported by: _elementtree
`xml.etree.ElementPath` SourceModule
imports: re • xml.etree
imported by: _elementtree • xml.etree • xml.etree.ElementTree
`xml.etree.ElementTree` SourceModule
imports: _elementtree • collections • collections.abc • contextlib • io • locale • pyexpat • re • sys • warnings • xml.etree • xml.etree.ElementPath • xml.parsers • xml.parsers.expat
imported by: _elementtree • test.support.testresult • xml.etree • xml.etree.ElementInclude • xml.etree.cElementTree
`xml.etree.cElementTree` SourceModule
imports: xml.etree • xml.etree.ElementTree
imported by: _elementtree
`xml.parsers` Package
imports: xml
imported by: xml.etree.ElementTree • xml.parsers.expat • xml.sax.expatreader • xmlrpc.client
`xml.parsers.expat` SourceModule
imports: pyexpat • sys • xml.parsers
imported by: plistlib • xml.etree.ElementTree • xml.sax.expatreader • xmlrpc.client
`xml.sax` Package
imports: 'org.python' • io • os • sys • xml • xml.sax • xml.sax._exceptions • xml.sax.expatreader • xml.sax.handler • xml.sax.saxutils • xml.sax.xmlreader
imported by: xml.sax • xml.sax._exceptions • xml.sax.expatreader • xml.sax.handler • xml.sax.saxutils • xml.sax.xmlreader
`xml.sax._exceptions` SourceModule
imports: 'java.lang' • sys • xml.sax
imported by: xml.sax • xml.sax.expatreader • xml.sax.xmlreader
`xml.sax.expatreader` SourceModule
imports: _weakref • sys • weakref • xml.parsers • xml.parsers.expat • xml.sax • xml.sax._exceptions • xml.sax.handler • xml.sax.saxutils • xml.sax.xmlreader
imported by: xml • xml.sax
`xml.sax.handler` SourceModule
imports: xml.sax
imported by: xml.sax • xml.sax.expatreader • xml.sax.saxutils • xml.sax.xmlreader
`xml.sax.saxutils` SourceModule
imports: codecs • io • os • sys • urllib.parse • urllib.request • xml.sax • xml.sax.handler • xml.sax.xmlreader
imported by: xml.sax • xml.sax.expatreader • xml.sax.xmlreader
`xml.sax.xmlreader` SourceModule
imports: xml.sax • xml.sax._exceptions • xml.sax.handler • xml.sax.saxutils
imported by: xml • xml.sax • xml.sax.expatreader • xml.sax.saxutils
`xmlrpc` Package
imported by: xmlrpc.client
`xmlrpc.client` SourceModule
imports: base64 • datetime • decimal • errno • gzip • http.client • io • sys • time • urllib.parse • xml.parsers • xml.parsers.expat • xmlrpc
imported by: multiprocessing.connection
`zipfile` SourceModule
imports: argparse • binascii • bz2 • importlib.util • io • lzma • os • py_compile • shutil • stat • struct • sys • threading • time • warnings • zlib
imported by: shutil • test.support.script_helper
`zipimport` (builtin module)
imports: zlib
imported by: pkgutil
`zlib` (builtin module)
imported by: encodings.zlib_codec • gzip • shutil • tarfile • test.support • zipfile • zipimport